type token =
  | SPEC of (Filepath.position * string)
  | DECL of (Logic_ptree.decl list)
  | CODE_ANNOT of (Logic_ptree.code_annot * Cabs.cabsloc)
  | LOOP_ANNOT of (Logic_ptree.code_annot list * Cabs.cabsloc)
  | ATTRIBUTE_ANNOT of (string * Cabs.cabsloc)
  | IDENT of (string)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | BOOL of (Cabs.cabsloc)
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | THREAD_LOCAL of (Cabs.cabsloc)
  | GHOST of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | COLON2
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | NORETURN of (Cabs.cabsloc)
  | STATIC_ASSERT of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_EOL
  | LGHOST
  | RGHOST
  | LGHOST_ELSE of (Cabs.cabsloc)

open Parsing;;
let _ = parse_error;;
# 50 "src/kernel_internals/parsing/cparser.mly"

open Cabs
open Cabshelper
(* This function is used by the parsing engine generated by Ocamlyacc itself,
   and requires a string as argument. *)
let parse_error msg = Errorloc.parse_error "%s" msg

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> { expr_loc = cabslu; expr_node = NOTHING }
  | [expr] -> expr
  | _ ->
      let beg_loc = fst (List.hd lst).expr_loc in
      let end_loc = snd (Extlib.last lst).expr_loc in
      { expr_loc = (beg_loc,end_loc); expr_node = COMMA (lst) }

let merge_string (c1,(b1,_)) (l2,(_,e2)) = c1 :: l2, (b1,e2)

(* To be called only inside a grammar rule. *)
let make_expr e =
  { expr_loc = Cil_datatype.Location.of_lexing_loc (symbol_start_pos (), symbol_end_pos ());
    expr_node = e }

let currentFunctionName = ref "<outside any function>"

exception NoProto

(* Go through all the parameter names and mark them as identifiers *)
let rec findProto = function
    PROTO (d, args, _,_) when isJUSTBASE d ->
      List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args
  | PROTO (d, _,_, _) -> findProto d
  | PARENTYPE (_, d, _) -> findProto d
  | PTR (_, d) -> findProto d
  | ARRAY (d, _, _) -> findProto d
  | _ -> raise NoProto

and isJUSTBASE = function
    JUSTBASE -> true
  | PARENTYPE (_, d, _) -> isJUSTBASE d
  | _ -> false

let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body.
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (try findProto decl
   with NoProto ->
     Errorloc.parse_error "Cannot find the prototype in a function definition");
  currentFunctionName := n

let check_funspec_abrupt_clauses fname spec =
  List.iter
    (fun bhv ->
      List.iter
	(function
	| (Cil_types.Normal | Cil_types.Exits),_ -> ()
	| (Cil_types.Breaks | Cil_types.Continues | Cil_types.Returns),
          { Logic_ptree.tp_statement = { lexpr_loc = (loc,_)}} ->
          Errorloc.parse_error ~source:loc
            "Specification of function %s can only contain ensures or \
                 exits post-conditions" fname)
	bhv.Logic_ptree.b_post_cond)
    spec.Logic_ptree.spec_behavior

let applyPointer (ptspecs: attribute list list) (dt: decl_type)
       : decl_type =
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration logic_spec (loc: cabsloc) (specs: spec_elem list) (nl: init_name list)  =
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      !Lexerhack.push_context ();
      List.iter
        (fun ((_,t,_,_),_) ->
           try findProto t with NoProto -> ())
        nl;
      let logic_spec =
        match logic_spec with
        | None -> None
        | Some (loc, _ as ls) -> begin
            Option.map
              (fun (loc', spec) ->
                 let name =
                   match nl with
                   | [ (n,_,_,_),_ ] -> n
                   | _ -> "unknown function"
                 in
                 check_funspec_abrupt_clauses name spec;
                 (spec, (loc, loc')))
              (Logic_lexer.spec ls)
          end
      in
      !Lexerhack.pop_context ();
      DECDEF (logic_spec, (specs, nl), loc)
    end

let in_ghost =
  let ghost_me = object
    inherit Cabsvisit.nopCabsVisitor
    method! vstmt s =
      s.stmt_ghost <- true;
      Cil.DoChildren
  end
  in
  List.map
    (fun s -> ignore (Cabsvisit.visitCabsStatement ghost_me s); s)

let ghost_global = ref false

let doFunctionDef spec (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list)
                  (n: name)
                  (b: block) : definition =
  let fname = (specs, n) in
  let name = match n with (n,_,_,_) -> n in
  Option.iter (fun (spec, _) -> check_funspec_abrupt_clauses name spec) spec;
  let b = if !ghost_global then { b with bstmts = in_ghost b.bstmts } else b in
  FUNDEF (spec, fname, b, loc, lend)

let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool))
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let int64_to_char value =
  if (Int64.compare value (Int64.of_int 255) > 0) ||
    (Int64.compare value Int64.zero < 0) then
    Errorloc.parse_error "integral literal 0x%Lx too big" value
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let intlist_to_string str =
  let buffer = Buffer.create 64 in
  let add_char c =
    Buffer.add_char buffer (int64_to_char c)
  in
  let add_char_list l = List.iter add_char l in
  List.iter add_char_list str ;
  Buffer.contents buffer

let fst3 (result, _, _) = result
let trd3 (_, _, result) = result

let fourth4 (_,_,_,result) = result

let sizeofType () =
  let findSpecifier name =
    let convert_one_specifier s =
      if s = "int" then Cabs.Tint
      else if s = "unsigned" then Cabs.Tunsigned
      else if s = "long" then Cabs.Tlong
      else if s = "short" then Cabs.Tshort
      else if s = "char" then Cabs.Tchar
      else
        Kernel.fatal
          ~current:true
          "initCIL: cannot find the right specifier for type %s" name
    in
    let add_one_specifier s acc =
      (Cabs.SpecType (convert_one_specifier s)) :: acc
    in
    let specs = Str.split (Str.regexp " +") name in
    List.fold_right add_one_specifier specs []
  in
  findSpecifier Cil.theMachine.Cil.theMachine.Cil_types.size_t


(*
   transform:  offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let transformOffsetOf (speclist, dtype) member =
  let mk_expr e = { expr_loc = member.expr_loc; expr_node = e } in
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, gnames, variadic) ->
	PROTO (addPointer dtype, names, gnames,variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = mk_expr (CONSTANT (CONST_INT "0")) in
  let castExpr = mk_expr (CAST (nullType, SINGLE_INIT nullExpr)) in

  let rec replaceBase e =
    let node = match e.expr_node with
      | VARIABLE field ->
	  MEMBEROFPTR (castExpr, field)
      | MEMBEROF (base, field) ->
	  MEMBEROF (replaceBase base, field)
      | INDEX (base, index) ->
	  INDEX (replaceBase base, index)
      | _ ->
	Errorloc.parse_error "malformed offset expression in offsetof macro"
    in { e with expr_node = node }
  in
  let memberExpr = replaceBase member in
  let addrExpr = { memberExpr with expr_node = UNARY (ADDROF, memberExpr)} in
  let sizeofType = sizeofType(), JUSTBASE in
  { addrExpr with expr_node = CAST (sizeofType, SINGLE_INIT addrExpr)}

let no_ghost_stmt s = {stmt_ghost = false ; stmt_node = s}
let ghost_stmt s = {stmt_ghost = true ; stmt_node = s}

let no_ghost = List.map no_ghost_stmt

let in_block l =
  match l with
      [] -> no_ghost_stmt (NOP cabslu)
    | [s] -> s
    | _::_ ->
        no_ghost_stmt (BLOCK ({ blabels = []; battrs = []; bstmts = l},
                              get_statementloc (List.hd l),
                              get_statementloc (Extlib.last l)))

let in_ghost_block ?(battrs=[]) l =
  let l = in_ghost l in
  ghost_stmt (BLOCK ({ blabels = []; battrs ; bstmts = l},
                       get_statementloc (List.hd l),
                       get_statementloc (Extlib.last l)))

# 394 "src/kernel_internals/parsing/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  297 (* EQ *);
  298 (* PLUS_EQ *);
  299 (* MINUS_EQ *);
  300 (* STAR_EQ *);
  301 (* SLASH_EQ *);
  302 (* PERCENT_EQ *);
  303 (* AND_EQ *);
  304 (* PIPE_EQ *);
  305 (* CIRC_EQ *);
  306 (* INF_INF_EQ *);
  307 (* SUP_SUP_EQ *);
  308 (* ARROW *);
  309 (* DOT *);
  310 (* EQ_EQ *);
  311 (* EXCLAM_EQ *);
  312 (* INF *);
  313 (* SUP *);
  314 (* INF_EQ *);
  315 (* SUP_EQ *);
  319 (* SLASH *);
  320 (* PERCENT *);
  323 (* PIPE *);
  324 (* CIRC *);
  327 (* PIPE_PIPE *);
  328 (* INF_INF *);
  329 (* SUP_SUP *);
  332 (* RPAREN *);
  336 (* LBRACKET *);
  337 (* RBRACKET *);
  338 (* COLON *);
  339 (* COLON2 *);
  341 (* COMMA *);
  342 (* ELLIPSIS *);
  343 (* QUEST *);
  358 (* ELSE *);
  367 (* LABEL__ *);
  369 (* BLOCKATTRIBUTE *);
  377 (* PRAGMA_EOL *);
  378 (* LGHOST *);
  379 (* RGHOST *);
    0|]

let yytransl_block = [|
  257 (* SPEC *);
  258 (* DECL *);
  259 (* CODE_ANNOT *);
  260 (* LOOP_ANNOT *);
  261 (* ATTRIBUTE_ANNOT *);
  262 (* IDENT *);
  263 (* CST_CHAR *);
  264 (* CST_WCHAR *);
  265 (* CST_INT *);
  266 (* CST_FLOAT *);
  267 (* NAMED_TYPE *);
  268 (* CST_STRING *);
  269 (* CST_WSTRING *);
  270 (* BOOL *);
  271 (* CHAR *);
  272 (* INT *);
  273 (* DOUBLE *);
  274 (* FLOAT *);
  275 (* VOID *);
  276 (* INT64 *);
  277 (* ENUM *);
  278 (* STRUCT *);
  279 (* TYPEDEF *);
  280 (* UNION *);
  281 (* SIGNED *);
  282 (* UNSIGNED *);
  283 (* LONG *);
  284 (* SHORT *);
  285 (* VOLATILE *);
  286 (* EXTERN *);
  287 (* STATIC *);
  288 (* CONST *);
  289 (* RESTRICT *);
  290 (* AUTO *);
  291 (* REGISTER *);
  292 (* THREAD *);
  293 (* THREAD_LOCAL *);
  294 (* GHOST *);
  295 (* SIZEOF *);
  296 (* ALIGNOF *);
  316 (* PLUS *);
  317 (* MINUS *);
  318 (* STAR *);
  321 (* TILDE *);
  322 (* AND *);
  325 (* EXCLAM *);
  326 (* AND_AND *);
  330 (* PLUS_PLUS *);
  331 (* MINUS_MINUS *);
  333 (* LPAREN *);
  334 (* RBRACE *);
  335 (* LBRACE *);
  340 (* SEMICOLON *);
  344 (* BREAK *);
  345 (* CONTINUE *);
  346 (* GOTO *);
  347 (* RETURN *);
  348 (* SWITCH *);
  349 (* CASE *);
  350 (* DEFAULT *);
  351 (* WHILE *);
  352 (* DO *);
  353 (* FOR *);
  354 (* IF *);
  355 (* TRY *);
  356 (* EXCEPT *);
  357 (* FINALLY *);
  359 (* ATTRIBUTE *);
  360 (* INLINE *);
  361 (* NORETURN *);
  362 (* STATIC_ASSERT *);
  363 (* ASM *);
  364 (* TYPEOF *);
  365 (* FUNCTION__ *);
  366 (* PRETTY_FUNCTION__ *);
  368 (* BUILTIN_VA_ARG *);
  370 (* BUILTIN_TYPES_COMPAT *);
  371 (* BUILTIN_OFFSETOF *);
  372 (* DECLSPEC *);
  373 (* MSASM *);
  374 (* MSATTR *);
  375 (* PRAGMA_LINE *);
  376 (* PRAGMA *);
  380 (* LGHOST_ELSE *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\003\000\049\000\050\000\
\050\000\050\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\053\000\053\000\054\000\055\000\055\000\
\056\000\056\000\056\000\056\000\057\000\057\000\057\000\057\000\
\057\000\057\000\057\000\057\000\057\000\057\000\057\000\059\000\
\059\000\059\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\062\000\062\000\063\000\063\000\063\000\063\000\064\000\064\000\
\064\000\065\000\065\000\065\000\066\000\066\000\066\000\066\000\
\066\000\067\000\067\000\067\000\068\000\068\000\069\000\069\000\
\070\000\070\000\071\000\071\000\072\000\072\000\073\000\073\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\010\000\008\000\008\000\008\000\
\008\000\008\000\008\000\009\000\076\000\076\000\075\000\075\000\
\075\000\075\000\077\000\077\000\077\000\012\000\012\000\018\000\
\018\000\060\000\060\000\017\000\017\000\017\000\078\000\078\000\
\019\000\019\000\019\000\020\000\020\000\079\000\058\000\058\000\
\080\000\015\000\015\000\011\000\011\000\013\000\013\000\081\000\
\081\000\014\000\016\000\032\000\082\000\083\000\083\000\033\000\
\033\000\033\000\033\000\085\000\085\000\087\000\087\000\034\000\
\034\000\035\000\035\000\088\000\088\000\089\000\089\000\089\000\
\089\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
\086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
\086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
\086\000\090\000\090\000\095\000\096\000\091\000\091\000\097\000\
\097\000\098\000\028\000\028\000\028\000\028\000\028\000\101\000\
\101\000\038\000\038\000\102\000\102\000\103\000\037\000\037\000\
\104\000\104\000\104\000\104\000\104\000\104\000\104\000\104\000\
\104\000\021\000\021\000\108\000\108\000\106\000\106\000\107\000\
\107\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\022\000\022\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\041\000\041\000\
\040\000\040\000\040\000\027\000\027\000\026\000\026\000\039\000\
\110\000\110\000\110\000\042\000\042\000\042\000\042\000\042\000\
\099\000\100\000\112\000\112\000\112\000\025\000\025\000\025\000\
\025\000\024\000\113\000\036\000\036\000\052\000\052\000\052\000\
\114\000\114\000\046\000\047\000\047\000\031\000\031\000\045\000\
\045\000\043\000\043\000\043\000\043\000\044\000\044\000\029\000\
\029\000\030\000\030\000\030\000\030\000\030\000\048\000\048\000\
\048\000\048\000\048\000\005\000\005\000\006\000\006\000\006\000\
\105\000\105\000\105\000\105\000\105\000\092\000\092\000\111\000\
\111\000\111\000\111\000\111\000\111\000\116\000\116\000\109\000\
\109\000\051\000\051\000\051\000\051\000\118\000\118\000\118\000\
\118\000\118\000\118\000\119\000\119\000\119\000\120\000\120\000\
\121\000\121\000\121\000\122\000\122\000\123\000\123\000\123\000\
\124\000\124\000\124\000\124\000\124\000\124\000\124\000\125\000\
\125\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
\125\000\125\000\126\000\127\000\127\000\127\000\127\000\128\000\
\128\000\128\000\129\000\129\000\129\000\130\000\130\000\130\000\
\130\000\130\000\131\000\131\000\131\000\132\000\132\000\133\000\
\133\000\134\000\134\000\135\000\135\000\136\000\136\000\137\000\
\137\000\139\000\139\000\138\000\117\000\140\000\140\000\141\000\
\141\000\084\000\115\000\007\000\007\000\007\000\093\000\093\000\
\094\000\094\000\142\000\142\000\144\000\144\000\145\000\143\000\
\143\000\146\000\146\000\147\000\147\000\147\000\149\000\149\000\
\148\000\148\000\000\000\000\000"

let yylen = "\002\000\
\001\000\002\000\000\000\002\000\003\000\002\000\001\000\002\000\
\002\000\001\000\001\000\001\000\001\000\003\000\005\000\005\000\
\001\000\006\000\004\000\001\000\001\000\001\000\000\000\001\000\
\001\000\001\000\001\000\003\000\001\000\002\000\005\000\006\000\
\006\000\006\000\003\000\003\000\002\000\002\000\006\000\001\000\
\003\000\002\000\001\000\002\000\002\000\002\000\004\000\002\000\
\004\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\001\000\004\000\001\000\003\000\003\000\003\000\001\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\005\000\
\001\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\001\000\002\000\
\002\000\002\000\001\000\001\000\001\000\001\000\003\000\001\000\
\003\000\000\000\001\000\003\000\002\000\001\000\001\000\000\000\
\003\000\004\000\005\000\000\000\001\000\002\000\000\000\001\000\
\005\000\000\000\001\000\000\000\001\000\001\000\003\000\000\000\
\001\000\003\000\003\000\005\000\001\000\000\000\002\000\001\000\
\003\000\003\000\003\000\000\000\001\000\002\000\004\000\000\000\
\004\000\001\000\003\000\001\000\002\000\000\000\002\000\003\000\
\005\000\001\000\002\000\002\000\001\000\004\000\003\000\004\000\
\006\000\009\000\004\000\004\000\006\000\003\000\002\000\003\000\
\002\000\002\000\003\000\004\000\008\000\007\000\001\000\005\000\
\004\000\000\000\001\000\001\000\001\000\002\000\001\000\000\000\
\001\000\005\000\003\000\002\000\004\000\003\000\001\000\004\000\
\006\000\001\000\003\000\001\000\003\000\002\000\001\000\003\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\002\000\002\000\002\000\002\000\000\000\001\000\000\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\002\000\003\000\005\000\004\000\
\006\000\005\000\002\000\005\000\004\000\006\000\005\000\002\000\
\006\000\005\000\007\000\006\000\001\000\004\000\004\000\000\000\
\003\000\002\000\004\000\002\000\001\000\003\000\001\000\003\000\
\001\000\004\000\002\000\001\000\003\000\001\000\003\000\003\000\
\002\000\004\000\003\000\001\000\004\000\004\000\004\000\005\000\
\001\000\002\000\000\000\002\000\003\000\002\000\002\000\001\000\
\003\000\002\000\005\000\001\000\003\000\000\000\004\000\004\000\
\001\000\003\000\003\000\000\000\001\000\002\000\001\000\003\000\
\001\000\004\000\004\000\004\000\003\000\001\000\000\000\003\000\
\002\000\002\000\002\000\005\000\005\000\004\000\001\000\001\000\
\001\000\001\000\001\000\000\000\002\000\000\000\002\000\005\000\
\004\000\002\000\001\000\001\000\001\000\000\000\002\000\001\000\
\001\000\001\000\001\000\001\000\001\000\004\000\002\000\001\000\
\002\000\002\000\003\000\004\000\001\000\001\000\001\000\003\000\
\001\000\001\000\003\000\001\000\001\000\001\000\001\000\002\000\
\001\000\002\000\003\000\001\000\001\000\001\000\003\000\001\000\
\001\000\002\000\003\000\002\000\003\000\003\000\004\000\001\000\
\002\000\004\000\002\000\004\000\002\000\002\000\002\000\002\000\
\002\000\002\000\001\000\001\000\003\000\003\000\003\000\001\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\003\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\001\000\
\003\000\001\000\003\000\001\000\003\000\001\000\003\000\001\000\
\006\000\001\000\003\000\000\000\001\000\001\000\003\000\000\000\
\001\000\003\000\003\000\000\000\002\000\002\000\001\000\002\000\
\000\000\003\000\000\000\001\000\001\000\003\000\005\000\000\000\
\003\000\000\000\003\000\000\000\002\000\003\000\001\000\003\000\
\000\000\002\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\011\000\075\001\000\000\005\001\
\236\000\235\000\238\000\242\000\241\000\234\000\240\000\000\000\
\000\000\217\000\000\000\243\000\244\000\239\000\237\000\072\001\
\000\000\219\000\071\001\073\001\220\000\221\000\084\001\085\001\
\074\001\000\000\000\000\222\000\223\000\000\000\000\000\000\000\
\000\000\083\001\101\001\000\000\007\000\203\001\001\000\000\000\
\000\000\000\000\000\000\012\000\013\000\000\000\224\000\000\000\
\017\000\207\000\000\000\225\000\204\001\000\000\218\000\000\000\
\000\000\000\000\000\000\020\000\021\000\000\000\000\000\000\000\
\022\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\115\000\116\000\117\000\000\000\108\000\000\000\
\006\000\000\000\000\000\000\000\000\000\000\000\082\001\000\000\
\000\000\109\001\000\000\106\001\105\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\098\001\
\120\001\000\000\000\000\110\001\000\000\121\001\000\000\139\001\
\140\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\173\001\002\000\004\000\000\000\
\204\000\067\001\000\000\000\000\000\000\053\001\000\000\000\000\
\000\000\227\000\233\000\149\000\065\001\000\000\010\000\000\000\
\000\000\000\000\231\000\226\000\000\000\206\000\000\000\064\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\020\001\000\000\000\000\095\001\000\000\000\000\000\000\097\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\014\000\
\110\000\000\000\000\000\025\000\104\000\105\000\102\000\103\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\026\000\106\000\000\000\027\000\029\000\000\000\057\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\089\000\101\000\107\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\129\001\000\000\
\131\001\133\001\134\001\135\001\138\001\136\001\137\001\000\000\
\000\000\000\000\122\001\000\000\099\001\102\001\103\001\117\001\
\000\000\000\000\116\001\124\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\172\001\000\000\093\001\091\001\089\001\090\001\092\001\
\000\000\088\001\000\000\000\000\203\000\000\000\000\000\000\000\
\028\001\042\001\229\000\228\000\000\000\000\000\008\000\009\000\
\005\000\000\000\000\000\205\000\000\000\019\000\000\000\070\001\
\201\000\000\000\000\000\038\001\039\001\000\000\000\000\000\000\
\034\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\010\001\000\000\000\000\000\000\000\000\000\000\000\000\
\248\000\012\001\000\000\000\000\000\000\000\000\253\000\000\000\
\000\000\000\000\000\000\000\000\000\000\177\001\000\000\081\001\
\113\000\114\000\000\000\046\000\000\000\048\000\050\000\051\000\
\052\000\055\000\053\000\054\000\056\000\000\000\044\000\045\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\208\000\
\000\000\000\000\000\000\037\000\038\000\000\000\000\000\030\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\112\000\000\000\
\006\001\054\001\000\000\007\001\000\000\178\001\107\001\000\000\
\000\000\119\001\104\001\123\001\100\001\112\001\000\000\125\001\
\126\001\000\000\141\001\142\001\143\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\171\001\051\001\077\001\
\000\000\211\000\000\000\000\000\000\000\118\000\216\000\000\000\
\000\000\000\000\000\000\024\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\045\001\033\001\000\000\000\000\000\000\
\041\001\000\000\000\000\000\000\000\000\036\001\000\000\068\001\
\023\001\021\001\002\001\094\001\000\000\000\000\000\000\019\001\
\009\001\000\000\000\000\000\000\014\001\247\000\250\000\000\000\
\252\000\255\000\000\000\015\000\179\001\000\000\000\000\000\000\
\000\000\146\000\000\000\028\000\000\000\000\000\000\000\000\000\
\036\000\035\000\139\000\000\000\000\000\090\000\091\000\092\000\
\093\000\094\000\095\000\096\000\097\000\098\000\099\000\100\000\
\060\000\061\000\062\000\059\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\141\000\016\000\000\000\175\001\
\000\000\000\000\115\001\127\001\000\000\214\000\000\000\087\001\
\000\000\000\000\000\000\126\000\000\000\123\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\079\001\000\000\000\000\151\000\000\000\
\000\000\000\000\000\000\157\000\069\001\000\000\000\000\000\000\
\018\000\000\000\000\000\000\000\056\001\000\000\000\000\037\001\
\001\001\004\001\000\000\000\000\016\001\011\001\249\000\254\000\
\000\000\000\000\000\000\143\000\000\000\058\000\000\000\000\000\
\000\000\209\000\000\000\147\000\000\000\000\000\000\000\213\000\
\000\000\000\000\000\000\127\000\000\000\134\000\119\000\125\000\
\029\001\031\001\000\000\000\000\145\000\025\001\030\001\000\000\
\000\000\000\000\161\000\163\000\158\000\000\000\148\000\000\000\
\197\000\000\000\170\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\191\000\000\000\000\000\
\173\000\000\000\000\000\000\000\000\000\195\000\196\000\000\000\
\000\000\000\000\000\000\061\001\000\000\000\000\003\001\018\001\
\000\000\000\000\000\000\040\000\000\000\000\000\031\000\136\000\
\088\000\169\001\133\000\129\000\000\000\000\000\121\000\124\000\
\043\001\027\001\000\000\000\000\032\001\000\000\000\000\164\000\
\000\000\171\000\185\000\186\000\000\000\000\000\183\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\172\000\153\000\155\000\000\000\154\000\000\000\
\000\000\000\000\202\000\050\001\047\001\048\001\058\001\060\001\
\059\001\039\000\032\000\033\000\000\000\034\000\042\000\000\000\
\130\000\000\000\026\001\080\001\159\000\165\000\000\000\187\000\
\184\000\175\000\000\000\000\000\182\000\000\000\000\000\000\000\
\181\001\182\001\000\000\000\000\000\000\000\000\000\000\000\000\
\041\000\000\000\131\000\188\000\180\000\000\000\000\000\000\000\
\174\000\000\000\193\000\000\000\000\000\000\000\179\000\176\000\
\000\000\000\000\199\000\000\000\000\000\000\000\167\000\000\000\
\192\000\000\000\184\001\000\000\000\000\000\000\198\000\000\000\
\137\000\181\000\000\000\000\000\000\000\000\000\000\000\189\001\
\000\000\000\000\177\000\000\000\000\000\000\000\000\000\000\000\
\186\001\000\000\000\000\190\000\000\000\169\000\189\000\195\001\
\000\000\190\001\000\000\000\000\000\000\193\001\000\000\178\000\
\000\000\000\000\197\001\000\000\191\001\202\001\000\000\198\001\
\200\001"

let yydgoto = "\003\000\
\046\000\047\000\048\000\049\000\041\001\220\001\226\002\217\000\
\218\000\121\001\052\002\068\002\167\002\220\000\020\002\136\001\
\069\002\070\002\071\002\196\002\178\000\051\000\179\000\138\000\
\166\000\169\000\170\000\052\000\053\000\054\000\242\000\169\002\
\090\002\054\001\223\001\163\000\139\000\140\000\101\001\086\001\
\087\001\235\001\236\001\237\001\179\002\142\000\088\001\055\000\
\056\000\154\000\180\000\232\001\114\000\049\001\077\001\221\000\
\222\000\191\002\189\002\073\002\223\000\224\000\225\000\226\000\
\227\000\228\000\229\000\230\000\231\000\232\000\233\000\234\000\
\235\000\236\000\237\000\087\000\238\000\133\002\074\002\192\002\
\142\002\150\000\226\001\095\000\091\002\208\002\209\002\210\002\
\025\003\173\002\036\003\209\001\030\003\045\003\174\002\175\002\
\064\001\065\001\067\000\167\000\181\000\210\001\211\001\059\000\
\060\000\156\000\146\000\147\000\075\000\080\002\043\001\073\001\
\050\001\096\002\195\000\076\000\243\000\116\000\117\000\010\001\
\011\001\012\001\118\000\119\000\120\000\121\000\122\000\123\000\
\124\000\125\000\126\000\127\000\128\000\129\000\130\000\131\000\
\132\000\205\001\133\000\244\000\103\001\054\003\065\003\055\003\
\056\003\057\003\078\003\083\003\084\003"

let yysindex = "\014\002\
\190\006\190\006\000\000\054\017\000\000\000\000\243\254\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\033\255\
\065\000\000\000\142\000\000\000\000\000\000\000\000\000\000\000\
\089\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\190\006\010\255\000\000\000\000\046\255\151\255\153\255\
\172\255\000\000\000\000\242\012\000\000\000\000\000\000\193\000\
\190\006\251\254\153\019\000\000\000\000\252\254\000\000\165\004\
\000\000\000\000\078\018\000\000\000\000\179\255\000\000\239\255\
\252\254\059\255\160\017\000\000\000\000\062\000\213\255\172\255\
\000\000\126\255\021\000\012\255\209\012\031\000\111\000\209\012\
\041\000\144\000\000\000\000\000\000\000\071\009\000\000\089\255\
\000\000\253\255\009\028\089\255\217\013\151\029\000\000\000\000\
\051\000\000\000\000\000\000\000\000\000\086\028\104\028\151\029\
\151\029\151\029\151\029\151\029\151\029\151\029\053\000\000\000\
\000\000\089\000\119\255\000\000\173\000\000\000\056\000\000\000\
\000\000\157\001\004\001\048\001\178\001\095\001\104\000\106\000\
\120\000\108\000\194\000\148\000\000\000\000\000\000\000\035\002\
\000\000\000\000\118\000\126\000\251\000\000\000\132\255\153\019\
\153\019\000\000\000\000\000\000\000\000\124\000\000\000\165\004\
\165\004\190\006\000\000\000\000\078\255\000\000\233\000\000\000\
\238\000\002\255\002\001\160\017\020\001\014\001\016\001\061\001\
\000\000\023\001\253\255\000\000\062\000\062\000\027\001\000\000\
\209\012\129\000\053\001\209\012\056\001\209\012\209\012\058\001\
\076\001\209\012\209\012\077\001\078\018\190\006\251\254\000\000\
\000\000\151\029\091\001\000\000\000\000\000\000\000\000\000\000\
\092\255\181\028\199\028\009\028\009\028\009\028\009\028\009\028\
\009\028\092\001\020\029\020\029\103\013\093\001\106\001\111\001\
\000\000\000\000\246\255\000\000\000\000\238\001\000\000\062\003\
\176\001\113\001\107\001\188\001\144\001\126\001\148\001\127\001\
\142\001\204\000\000\000\000\000\000\000\092\255\180\001\200\001\
\020\001\203\001\173\001\207\001\020\002\103\013\000\000\103\013\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\211\001\
\039\002\127\029\000\000\112\001\000\000\000\000\000\000\000\000\
\101\001\089\255\000\000\000\000\092\001\092\001\151\029\151\029\
\151\029\151\029\151\029\151\029\151\029\151\029\151\029\151\029\
\151\029\151\029\151\029\151\029\151\029\151\029\151\029\151\029\
\151\029\000\000\151\029\000\000\000\000\000\000\000\000\000\000\
\020\001\000\000\035\002\103\255\000\000\116\026\035\002\028\012\
\000\000\000\000\000\000\000\000\092\001\198\001\000\000\000\000\
\000\000\192\001\241\001\000\000\057\002\000\000\000\002\000\000\
\000\000\078\018\045\002\000\000\000\000\000\000\152\000\020\017\
\000\000\192\001\009\028\062\000\021\002\047\002\023\001\023\001\
\062\000\000\000\009\028\209\012\033\002\054\002\061\002\132\255\
\000\000\000\000\209\012\081\002\083\002\209\012\000\000\085\002\
\088\002\209\012\239\255\092\002\251\000\000\000\114\002\000\000\
\000\000\000\000\103\013\000\000\103\013\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\103\013\000\000\000\000\
\144\002\159\002\160\002\161\002\009\028\078\018\078\018\000\000\
\089\255\092\001\092\001\000\000\000\000\009\028\009\028\000\000\
\009\028\009\028\009\028\009\028\009\028\009\028\009\028\009\028\
\009\028\009\028\009\028\009\028\009\028\009\028\009\028\009\028\
\009\028\009\028\009\028\009\028\009\028\009\028\009\028\009\028\
\009\028\009\028\009\028\009\028\009\028\009\028\000\000\156\002\
\000\000\000\000\164\002\000\000\151\029\000\000\000\000\162\002\
\166\002\000\000\000\000\000\000\000\000\000\000\101\001\000\000\
\000\000\163\002\000\000\000\000\000\000\157\001\157\001\004\001\
\004\001\048\001\048\001\048\001\048\001\178\001\178\001\095\001\
\104\000\106\000\120\000\108\000\151\029\000\000\000\000\000\000\
\020\001\000\000\158\002\103\255\141\025\000\000\000\000\020\001\
\116\255\219\000\168\002\000\000\160\017\177\001\167\002\170\002\
\172\255\019\255\078\018\000\000\000\000\160\017\020\001\172\002\
\000\000\035\002\237\024\112\011\179\002\000\000\014\001\000\000\
\000\000\000\000\000\000\000\000\169\002\174\002\023\001\000\000\
\000\000\009\028\162\255\209\012\000\000\000\000\000\000\182\002\
\000\000\000\000\183\002\000\000\000\000\192\002\193\002\194\002\
\009\028\000\000\193\026\000\000\186\002\189\002\190\002\197\002\
\000\000\000\000\000\000\212\002\165\002\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\176\001\176\001\113\001\113\001\
\107\001\107\001\107\001\107\001\188\001\188\001\144\001\126\001\
\148\001\127\001\142\001\207\002\000\000\000\000\035\002\000\000\
\185\002\185\002\000\000\000\000\216\002\000\000\103\255\000\000\
\000\000\092\001\009\028\000\000\224\002\000\000\004\003\231\002\
\236\002\116\026\239\002\192\001\240\002\035\002\009\028\238\002\
\035\002\089\255\241\002\000\000\124\000\092\001\000\000\019\255\
\019\255\024\003\101\008\000\000\000\000\038\003\030\003\032\003\
\000\000\020\001\041\003\042\003\000\000\160\017\009\028\000\000\
\000\000\000\000\046\003\035\002\000\000\000\000\000\000\000\000\
\185\002\185\002\185\002\000\000\141\025\000\000\078\018\078\018\
\092\001\000\000\253\002\000\000\009\028\020\001\151\029\000\000\
\200\000\057\001\141\025\000\000\116\026\000\000\000\000\000\000\
\000\000\000\000\078\018\009\028\000\000\000\000\000\000\089\003\
\049\003\192\001\000\000\000\000\000\000\005\003\000\000\208\005\
\000\000\000\000\000\000\045\003\048\003\105\000\014\027\056\003\
\009\028\052\003\056\003\252\254\117\000\000\000\053\003\019\255\
\000\000\019\255\059\003\019\255\153\001\000\000\000\000\019\003\
\020\001\194\017\067\003\000\000\068\003\065\003\000\000\000\000\
\069\003\086\003\087\003\000\000\163\000\084\003\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\009\028\000\000\000\000\
\000\000\000\000\009\028\035\002\000\000\019\255\004\007\000\000\
\094\011\000\000\000\000\000\000\009\028\088\003\000\000\090\003\
\009\028\004\007\216\255\004\007\004\007\124\001\102\000\102\000\
\102\000\156\003\000\000\000\000\000\000\103\255\000\000\056\003\
\004\007\157\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\229\003\000\000\000\000\009\028\
\000\000\155\003\000\000\000\000\000\000\000\000\153\003\000\000\
\000\000\000\000\004\007\009\028\000\000\075\000\056\003\252\254\
\000\000\000\000\161\003\089\255\004\007\004\007\144\003\221\008\
\000\000\164\003\000\000\000\000\000\000\162\003\004\007\004\007\
\000\000\252\254\000\000\089\255\089\255\163\003\000\000\000\000\
\056\003\165\003\000\000\009\028\125\003\004\007\000\000\129\003\
\000\000\163\003\000\000\173\003\178\003\177\003\000\000\179\003\
\000\000\000\000\160\003\188\003\251\003\184\003\182\003\000\000\
\089\255\197\003\000\000\009\028\004\007\198\003\187\003\173\003\
\000\000\173\003\206\003\000\000\216\003\000\000\000\000\000\000\
\212\003\000\000\009\028\004\007\122\255\000\000\227\003\000\000\
\092\001\001\004\000\000\005\004\000\000\000\000\089\255\000\000\
\000\000"

let yyrindex = "\000\000\
\089\005\089\005\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\093\016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\028\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\028\000\231\000\011\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\084\001\000\000\000\000\000\000\000\000\231\000\
\000\000\044\018\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\075\014\000\000\209\000\010\004\181\014\000\000\010\004\
\031\015\000\000\000\000\000\000\000\000\000\000\000\000\119\007\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\185\011\
\101\012\000\000\015\012\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\210\029\000\000\089\030\000\000\
\000\000\212\030\095\016\076\026\184\031\022\006\162\006\153\014\
\214\012\055\011\229\000\063\001\000\000\000\000\000\000\190\001\
\000\000\000\000\006\004\000\000\078\001\000\000\000\000\011\001\
\011\001\000\000\000\000\000\000\000\000\224\004\000\000\000\000\
\000\000\028\000\000\000\000\000\044\018\000\000\000\000\000\000\
\015\004\013\004\000\000\000\000\049\001\017\004\000\000\160\255\
\000\000\016\004\000\000\000\000\000\000\000\000\000\000\000\000\
\010\004\231\000\000\000\010\004\018\004\010\004\010\004\137\015\
\000\000\010\004\010\004\000\000\000\000\019\004\231\000\000\000\
\000\000\022\004\000\000\000\000\000\000\000\000\000\000\000\000\
\159\009\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\046\002\000\000\170\016\
\166\018\208\019\159\020\234\021\155\022\017\023\135\023\253\023\
\115\024\117\019\000\000\000\000\000\000\249\009\000\000\000\000\
\042\001\000\000\207\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\072\009\001\030\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\212\001\000\000\061\025\227\000\000\000\000\000\007\001\116\000\
\000\000\000\000\000\000\000\000\000\000\088\005\000\000\000\000\
\000\000\013\004\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\044\001\000\000\000\000\000\000\154\002\020\004\000\000\
\000\000\013\004\000\000\021\004\000\000\000\000\016\004\016\004\
\000\000\000\000\000\000\010\004\123\001\011\004\000\000\000\000\
\000\000\000\000\010\004\000\000\000\000\010\004\000\000\000\000\
\000\000\010\004\231\000\000\000\184\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\105\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\025\004\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\026\004\000\000\000\000\
\000\000\000\000\020\004\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\048\030\000\000\
\000\000\000\000\000\000\000\000\000\000\253\030\038\031\079\031\
\120\031\153\026\230\026\130\027\161\031\208\031\231\031\255\031\
\047\014\003\015\219\013\105\015\000\000\000\000\000\000\000\000\
\231\000\000\000\028\004\072\006\024\004\000\000\000\000\231\000\
\044\018\093\027\000\000\000\000\000\000\224\001\000\000\045\255\
\000\000\237\007\030\004\000\000\000\000\000\000\231\000\034\004\
\000\000\182\000\070\002\000\001\000\000\000\000\017\004\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\016\004\000\000\
\000\000\000\000\231\000\010\004\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\235\018\048\019\021\020\090\020\
\227\020\039\021\107\021\175\021\037\022\096\022\214\022\076\023\
\194\023\056\024\174\024\000\000\000\000\000\000\184\000\000\000\
\130\030\171\030\000\000\000\000\000\000\000\000\227\000\000\000\
\080\032\000\000\000\000\000\000\038\004\000\000\170\027\000\000\
\000\000\000\000\000\000\203\024\000\000\038\029\023\004\000\000\
\218\025\000\000\000\000\000\000\224\004\000\000\000\000\181\003\
\045\004\000\000\080\001\000\000\000\000\000\000\033\004\000\000\
\000\000\132\000\044\018\044\018\000\000\000\000\023\004\000\000\
\000\000\000\000\000\000\187\001\000\000\000\000\000\000\000\000\
\173\010\007\011\000\000\000\000\024\004\000\000\000\000\000\000\
\000\000\000\000\083\010\000\000\000\000\222\000\000\000\000\000\
\039\026\000\000\024\004\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\030\004\000\000\000\000\000\000\000\000\247\027\
\000\000\203\024\000\000\000\000\000\000\000\000\000\000\165\001\
\000\000\243\015\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\041\004\000\000\000\000\181\003\
\000\000\181\003\000\000\181\003\000\000\000\000\000\000\000\000\
\231\000\044\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\039\026\000\000\000\000\000\000\
\000\000\000\000\000\000\128\004\000\000\181\003\165\001\000\000\
\165\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\165\001\000\000\165\001\165\001\000\000\041\004\041\004\
\041\004\000\000\000\000\000\000\000\000\072\006\000\000\000\000\
\165\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\025\004\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\165\001\000\000\000\000\061\003\000\000\000\000\
\000\000\000\000\000\000\000\000\165\001\165\001\000\000\037\004\
\000\000\000\000\000\000\000\000\000\000\000\000\165\001\165\001\
\000\000\000\000\000\000\000\000\215\255\027\004\000\000\000\000\
\000\000\000\000\000\000\037\004\000\000\165\001\000\000\000\000\
\000\000\027\004\000\000\068\255\000\000\000\000\000\000\000\000\
\000\000\000\000\188\002\000\000\000\000\047\004\203\000\000\000\
\000\000\000\000\000\000\049\004\165\001\000\000\000\000\068\255\
\000\000\125\255\000\000\000\000\000\000\000\000\000\000\000\000\
\050\004\000\000\000\000\165\001\051\004\000\000\000\000\000\000\
\000\000\214\000\000\000\051\004\000\000\000\000\000\000\000\000\
\000\000"

let yygindex = "\000\000\
\000\000\126\005\248\255\000\000\141\255\166\003\189\000\000\000\
\063\000\167\255\116\254\220\254\038\000\147\254\138\002\198\002\
\000\000\000\000\238\253\204\002\033\000\019\000\221\255\000\000\
\109\255\070\004\144\255\206\255\058\000\143\005\199\255\251\255\
\148\254\071\003\201\253\146\255\205\003\210\255\211\255\000\000\
\172\003\029\005\000\000\000\000\145\255\100\255\244\255\000\000\
\000\000\129\002\006\000\061\254\240\255\034\000\245\254\000\000\
\000\000\000\000\000\000\215\253\015\000\023\002\147\001\172\001\
\235\001\182\001\012\004\043\004\014\004\042\004\009\004\000\000\
\050\003\085\003\128\255\180\255\245\255\000\000\000\000\000\000\
\075\003\000\000\000\000\200\255\211\253\213\253\225\254\007\255\
\000\000\000\000\000\000\059\254\052\000\173\002\000\000\000\000\
\211\254\000\000\235\254\056\254\022\000\145\003\000\000\114\000\
\252\255\000\000\237\002\000\000\055\000\000\000\254\254\226\003\
\000\000\034\003\043\005\000\000\237\255\000\000\150\255\207\004\
\035\004\000\000\000\000\000\000\000\000\021\001\128\002\147\002\
\118\002\205\002\188\004\189\004\190\004\191\004\187\004\000\000\
\241\254\000\000\000\000\075\255\000\000\201\002\000\000\000\000\
\200\002\000\000\000\000\140\002\135\002"

let yytablesize = 8615
let yytable = "\073\000\
\073\000\219\000\073\000\240\000\141\000\152\000\057\000\057\000\
\070\001\215\001\009\001\193\000\102\001\088\000\064\002\172\000\
\067\001\159\000\141\000\206\001\083\002\088\002\058\000\058\000\
\115\000\089\000\221\001\003\000\240\001\094\002\148\002\093\002\
\088\000\050\000\050\000\192\000\064\000\143\000\068\000\057\000\
\135\000\230\001\149\002\069\000\185\000\222\001\059\001\172\002\
\149\000\074\000\078\000\143\000\081\000\069\001\057\000\058\000\
\136\000\003\001\073\000\160\000\079\001\080\001\073\000\066\000\
\161\000\073\000\050\000\245\001\246\001\144\000\058\000\079\000\
\105\001\082\000\148\000\185\002\088\000\058\000\137\000\194\001\
\088\000\050\000\088\000\161\000\070\001\062\001\090\000\086\000\
\050\000\199\002\000\001\155\000\088\000\088\000\088\000\088\000\
\088\000\088\000\088\000\165\000\083\000\152\000\152\000\083\000\
\201\000\088\000\113\000\058\000\175\000\167\001\195\002\070\000\
\184\000\153\000\071\000\188\000\247\000\249\000\191\000\068\001\
\162\000\161\000\091\000\063\001\106\001\241\000\073\000\072\000\
\162\000\170\001\176\000\042\001\085\001\083\000\162\000\071\000\
\194\001\068\000\031\000\032\000\089\002\082\001\069\000\187\001\
\090\001\057\001\092\001\093\001\072\000\187\001\096\001\097\001\
\071\001\058\001\239\000\123\001\113\000\181\002\009\001\057\000\
\253\002\193\000\144\000\144\000\145\000\254\002\113\000\113\000\
\113\000\113\000\113\000\113\000\113\000\058\000\058\000\058\000\
\194\001\194\001\195\002\008\001\239\001\100\001\088\000\208\001\
\050\000\050\000\050\000\216\001\176\001\061\002\177\001\076\002\
\134\000\117\001\092\002\057\000\165\000\084\000\085\000\201\002\
\084\000\085\000\004\001\081\003\173\000\035\000\228\001\124\001\
\047\001\153\000\153\000\058\000\214\001\221\001\102\002\081\002\
\108\001\110\001\041\000\222\001\042\000\099\001\050\000\136\000\
\247\001\119\001\120\001\092\000\171\001\093\000\084\000\085\000\
\222\001\194\001\194\001\107\002\150\002\022\001\238\002\005\001\
\124\001\241\001\124\001\083\001\022\001\241\000\088\000\056\002\
\094\000\248\001\122\001\186\001\073\000\073\000\088\000\157\000\
\113\000\145\000\145\000\088\000\088\000\088\000\088\000\088\000\
\088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
\088\000\088\000\088\000\088\000\088\000\088\000\241\000\088\000\
\241\000\086\003\068\000\122\001\207\001\122\001\138\002\069\000\
\013\003\171\000\183\001\013\002\224\001\136\002\042\001\212\001\
\183\001\003\003\042\001\042\001\136\000\004\003\184\001\185\001\
\249\001\006\002\218\002\007\002\159\000\221\002\073\000\253\001\
\092\002\092\002\000\002\228\002\008\002\229\002\003\002\231\002\
\113\000\128\001\158\000\168\000\014\002\015\002\068\000\073\000\
\183\001\194\000\129\001\069\000\009\001\113\000\113\000\113\000\
\113\000\113\000\113\000\113\000\113\000\113\000\113\000\113\000\
\113\000\113\000\113\000\113\000\113\000\113\000\113\000\113\000\
\200\002\113\000\231\001\174\000\205\002\124\001\079\002\124\001\
\165\000\003\000\077\002\013\001\014\001\182\000\068\000\194\002\
\124\001\073\000\073\000\069\000\068\000\088\000\098\002\186\000\
\101\002\069\000\014\003\214\001\250\000\251\000\252\000\253\000\
\254\000\255\000\223\002\034\003\245\000\224\002\001\001\015\001\
\092\002\052\001\092\002\241\000\092\002\241\000\052\001\077\000\
\122\001\223\002\122\001\068\000\224\002\068\000\241\000\048\003\
\069\000\026\003\069\000\122\001\078\001\068\000\241\000\241\000\
\108\002\088\000\069\000\017\002\018\002\002\001\213\002\071\000\
\087\002\029\001\075\002\019\002\021\002\030\001\092\002\069\003\
\023\003\032\001\006\001\046\003\072\000\097\000\098\000\007\001\
\083\000\095\002\031\001\076\001\035\001\183\000\136\000\016\002\
\076\001\088\000\078\001\126\002\073\000\070\001\024\003\078\001\
\078\001\100\000\044\001\053\002\101\000\085\001\225\002\212\001\
\052\001\045\001\083\001\052\001\084\001\042\001\096\001\245\002\
\110\002\042\001\140\002\096\001\080\000\144\002\187\000\036\001\
\002\003\070\001\005\003\006\003\234\001\042\001\042\001\042\001\
\086\001\130\002\053\001\113\000\052\001\086\001\246\002\015\003\
\214\001\052\001\135\001\076\001\071\000\076\001\072\002\037\001\
\184\002\078\002\038\001\039\001\066\002\165\000\031\000\032\000\
\040\001\072\000\076\001\231\001\076\001\076\001\165\000\076\001\
\033\001\021\003\111\000\113\000\076\001\168\001\001\000\002\000\
\232\000\076\001\165\001\031\003\032\003\232\000\188\001\067\002\
\034\001\084\000\085\000\214\001\188\001\039\003\040\003\096\001\
\086\001\199\001\166\001\046\001\187\001\188\001\189\001\199\001\
\168\002\214\001\052\001\214\001\050\003\052\001\116\002\086\001\
\168\001\073\000\042\001\052\001\075\002\168\001\052\001\168\001\
\168\001\168\001\212\001\052\001\060\001\186\002\187\002\019\001\
\020\001\035\000\061\001\070\003\076\001\224\001\088\000\219\002\
\232\000\042\001\171\002\076\001\042\001\066\001\041\000\062\001\
\042\000\136\000\080\003\076\001\076\001\071\001\232\000\232\000\
\252\002\230\000\232\000\074\001\232\000\168\001\232\000\232\000\
\170\002\068\000\072\001\129\002\073\000\075\001\069\000\042\001\
\073\000\081\001\006\001\076\001\250\002\097\000\098\000\007\001\
\058\000\171\001\073\000\088\000\141\002\055\001\052\001\021\001\
\022\001\052\001\046\001\191\000\040\001\052\001\055\001\046\001\
\052\001\100\000\089\001\095\002\101\000\040\001\165\000\171\002\
\094\001\197\002\170\001\091\001\141\002\214\002\198\002\170\001\
\145\002\230\000\170\001\170\001\027\001\028\001\072\002\241\000\
\241\000\095\001\188\002\098\001\066\001\152\000\222\002\230\000\
\230\000\215\000\215\000\230\000\072\002\230\000\104\001\230\000\
\230\000\125\001\022\003\231\001\151\001\152\001\194\000\194\000\
\194\000\202\002\153\001\154\001\142\000\036\001\126\001\170\001\
\099\001\142\000\142\000\127\001\142\000\113\000\171\002\161\001\
\171\002\163\001\111\000\076\001\216\002\159\001\160\001\042\001\
\076\001\171\002\152\000\171\002\171\002\037\001\017\001\017\001\
\038\001\039\001\231\001\164\001\031\000\032\000\040\001\162\001\
\171\002\052\001\016\001\017\001\018\001\035\003\052\001\007\003\
\008\003\212\001\111\001\112\001\113\001\114\001\115\001\116\001\
\181\001\023\001\024\001\025\001\026\001\148\001\149\001\150\001\
\251\002\079\003\171\002\155\001\156\001\157\001\158\001\232\002\
\233\002\234\002\255\002\076\001\171\002\171\002\122\001\168\001\
\029\003\173\001\027\003\194\000\194\000\194\000\171\002\171\002\
\078\001\076\001\076\001\215\000\215\000\076\001\076\001\076\001\
\029\003\029\003\076\001\169\001\041\003\171\002\172\001\035\000\
\055\001\056\001\174\001\219\001\175\001\019\002\178\001\052\001\
\052\001\130\001\131\001\052\001\041\000\058\000\042\000\036\001\
\052\001\037\002\038\002\078\001\171\002\088\000\078\001\179\001\
\191\000\078\001\043\000\078\001\078\001\053\002\225\001\132\001\
\133\001\063\001\134\001\171\002\227\001\135\001\161\000\037\001\
\224\001\088\000\038\001\039\001\039\002\040\002\031\000\032\000\
\040\001\053\002\043\000\088\000\229\001\043\000\043\000\042\003\
\043\003\043\000\043\000\043\000\045\002\046\002\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\053\002\243\001\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\078\001\043\000\
\043\000\043\000\250\001\043\000\043\000\043\000\043\000\067\003\
\233\001\043\000\244\001\043\000\051\001\052\001\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\041\002\042\002\043\002\
\044\002\035\000\251\001\082\003\194\001\195\001\196\001\197\001\
\252\001\078\001\190\001\191\001\043\000\082\003\041\000\078\001\
\042\000\078\001\078\001\009\003\010\003\011\003\254\001\053\001\
\255\001\043\000\001\002\043\000\053\001\002\002\043\000\192\001\
\193\001\004\002\033\002\034\002\035\002\036\002\036\002\036\002\
\036\002\036\002\036\002\036\002\036\002\036\002\036\002\036\002\
\036\002\036\002\036\002\036\002\168\000\005\002\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\009\002\057\001\053\001\198\001\
\199\001\053\001\010\002\011\002\012\002\057\002\057\001\054\002\
\055\002\058\002\063\002\060\002\082\002\124\002\105\002\168\000\
\168\000\168\000\085\002\106\002\168\000\168\000\086\002\097\002\
\168\000\168\000\103\002\111\002\112\002\168\000\168\000\117\002\
\168\000\168\000\168\000\113\002\114\002\115\002\119\002\168\000\
\122\002\120\002\121\002\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\123\002\
\125\002\118\002\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\127\002\168\000\132\002\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\131\002\168\000\168\000\168\000\
\134\002\135\002\137\002\139\002\146\002\166\000\143\002\166\000\
\166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\151\002\137\001\138\001\
\139\001\140\001\141\001\142\001\143\001\144\001\145\001\146\001\
\147\001\176\002\177\002\178\002\076\002\180\002\190\002\203\002\
\166\000\166\000\166\000\183\002\204\002\166\000\166\000\206\002\
\211\002\166\000\166\000\212\002\217\002\220\002\166\000\166\000\
\227\002\166\000\166\000\166\000\230\002\235\002\239\002\240\002\
\166\000\241\002\242\002\036\002\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
\248\002\243\002\244\002\166\000\166\000\166\000\166\000\166\000\
\166\000\166\000\166\000\000\003\166\000\001\003\166\000\166\000\
\166\000\166\000\166\000\166\000\166\000\156\000\166\000\166\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\022\002\023\002\024\002\
\025\002\026\002\027\002\028\002\029\002\030\002\031\002\032\002\
\012\003\016\003\017\003\019\003\020\003\028\003\033\003\037\003\
\156\000\156\000\156\000\038\003\044\003\156\000\156\000\049\003\
\047\003\156\000\156\000\051\003\053\003\058\003\156\000\156\000\
\063\003\156\000\156\000\156\000\059\003\061\003\060\003\062\003\
\156\000\064\003\066\003\072\003\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\068\003\071\003\075\003\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\076\003\156\000\077\003\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\085\003\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\087\003\081\003\008\001\
\003\000\210\000\044\001\200\000\035\001\023\000\015\001\013\001\
\003\000\176\001\024\000\063\001\138\000\122\000\185\001\144\000\
\156\000\156\000\156\000\140\000\046\001\156\000\156\000\212\000\
\069\001\156\000\156\000\120\000\049\001\180\001\156\000\156\000\
\140\000\156\000\192\001\156\000\140\000\196\001\201\001\061\000\
\156\000\018\003\247\002\084\002\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\249\002\242\001\065\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\147\002\156\000\062\002\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\004\000\109\002\156\000\
\076\001\006\000\062\000\048\001\047\002\051\002\193\002\008\000\
\049\002\182\002\009\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\063\000\026\000\027\000\028\000\029\000\030\000\
\031\000\032\000\033\000\076\001\048\002\050\002\076\001\128\002\
\104\002\076\001\236\002\076\001\076\001\078\001\052\003\182\001\
\200\001\059\002\201\001\204\001\202\001\089\003\203\001\088\003\
\160\000\000\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\073\003\074\003\000\000\035\000\036\000\037\000\038\000\000\000\
\040\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\041\000\000\000\042\000\160\000\160\000\160\000\000\000\151\000\
\160\000\160\000\000\000\000\000\160\000\160\000\000\000\000\000\
\000\000\160\000\160\000\000\000\160\000\160\000\160\000\000\000\
\000\000\000\000\000\000\160\000\000\000\000\000\000\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\160\000\160\000\160\000\000\000\000\000\000\000\160\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\000\000\160\000\
\160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
\150\000\160\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\150\000\150\000\150\000\000\000\000\000\
\150\000\150\000\000\000\000\000\150\000\150\000\000\000\000\000\
\000\000\150\000\150\000\000\000\150\000\150\000\150\000\000\000\
\000\000\000\000\000\000\150\000\000\000\000\000\000\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\000\000\000\000\000\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\000\000\150\000\
\000\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\207\002\150\000\088\002\153\002\006\000\065\002\197\000\198\000\
\199\000\200\000\154\002\083\000\201\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\063\000\026\000\027\000\
\028\000\029\000\030\000\031\000\032\000\033\000\202\000\203\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\204\000\205\000\206\000\000\000\000\000\
\207\000\208\000\000\000\000\000\209\000\210\000\000\000\000\000\
\000\000\211\000\212\000\000\000\213\000\000\000\148\000\000\000\
\000\000\000\000\000\000\155\002\000\000\000\000\000\000\156\002\
\157\002\158\002\159\002\160\002\161\002\162\002\000\000\000\000\
\000\000\163\002\164\002\000\000\000\000\000\000\035\000\036\000\
\037\000\000\000\165\002\040\000\084\000\085\000\158\001\214\000\
\000\000\215\000\216\000\041\000\166\002\042\000\000\000\000\000\
\086\001\089\002\086\001\086\001\000\000\086\001\086\001\086\001\
\086\001\086\001\086\001\086\001\086\001\000\000\000\000\158\001\
\158\001\158\001\000\000\158\001\158\001\000\000\000\000\000\000\
\000\000\158\001\000\000\000\000\000\000\000\000\158\001\000\000\
\158\001\158\001\158\001\000\000\158\001\000\000\086\001\086\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\086\001\086\001\086\001\000\000\000\000\
\086\001\086\001\000\000\000\000\086\001\086\001\158\001\000\000\
\000\000\086\001\086\001\000\000\086\001\000\000\086\001\000\000\
\000\000\000\000\000\000\086\001\000\000\000\000\000\000\086\001\
\086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
\086\001\086\001\086\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\086\001\000\000\086\001\086\001\000\000\086\001\
\000\000\086\001\086\001\000\000\086\001\000\000\004\000\005\000\
\000\000\086\001\006\000\007\000\000\000\000\000\000\000\000\000\
\008\000\000\000\160\001\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\025\000\026\000\027\000\028\000\029\000\
\030\000\031\000\032\000\033\000\160\001\160\001\000\000\160\001\
\160\001\000\000\000\000\000\000\000\000\160\001\000\000\000\000\
\000\000\000\000\160\001\000\000\160\001\160\001\160\001\000\000\
\160\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\207\002\000\000\088\002\153\002\
\000\000\065\002\197\000\198\000\199\000\200\000\069\000\083\000\
\201\000\034\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\160\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\035\000\036\000\037\000\038\000\
\039\000\040\000\202\000\203\000\000\000\000\000\000\000\000\000\
\000\000\041\000\000\000\042\000\043\000\044\000\000\000\045\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\204\000\
\205\000\206\000\000\000\000\000\207\000\208\000\000\000\000\000\
\209\000\210\000\000\000\000\000\000\000\211\000\212\000\000\000\
\213\000\000\000\148\000\000\000\000\000\000\000\000\000\155\002\
\000\000\000\000\000\000\156\002\157\002\158\002\159\002\160\002\
\161\002\162\002\000\000\000\000\000\000\163\002\164\002\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\165\002\000\000\
\084\000\085\000\000\000\214\000\000\000\215\000\216\000\109\000\
\166\002\000\000\000\000\109\000\109\000\089\002\000\000\109\000\
\109\000\109\000\000\000\000\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\000\000\000\000\109\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\000\000\
\109\000\109\000\109\000\000\000\109\000\109\000\109\000\109\000\
\000\000\000\000\109\000\109\000\000\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\000\000\109\000\000\000\000\000\
\000\000\000\000\000\000\000\000\109\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\109\000\109\000\109\000\
\109\000\000\000\109\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\109\000\000\000\109\000\156\000\000\000\109\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\156\000\156\000\156\000\000\000\000\000\156\000\156\000\000\000\
\000\000\156\000\156\000\000\000\000\000\000\000\156\000\156\000\
\000\000\156\000\156\000\156\000\000\000\000\000\000\000\000\000\
\156\000\000\000\000\000\000\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
\000\000\000\000\000\000\156\000\156\000\156\000\156\000\156\000\
\156\000\156\000\156\000\000\000\156\000\000\000\156\000\156\000\
\156\000\156\000\156\000\156\000\156\000\152\002\000\000\000\000\
\153\002\006\000\065\002\197\000\198\000\199\000\200\000\154\002\
\083\000\201\000\009\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\063\000\026\000\027\000\028\000\029\000\030\000\
\031\000\032\000\033\000\202\000\203\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\204\000\205\000\206\000\000\000\000\000\207\000\208\000\000\000\
\000\000\209\000\210\000\000\000\000\000\000\000\211\000\212\000\
\000\000\213\000\000\000\148\000\000\000\000\000\000\000\000\000\
\155\002\000\000\000\000\000\000\156\002\157\002\158\002\159\002\
\160\002\161\002\162\002\000\000\000\000\000\000\163\002\164\002\
\000\000\000\000\000\000\035\000\036\000\037\000\038\000\165\002\
\040\000\084\000\085\000\000\000\214\000\000\000\215\000\216\000\
\041\000\166\002\042\000\043\000\044\000\189\000\000\000\000\000\
\000\000\006\000\196\000\197\000\198\000\199\000\200\000\008\000\
\083\000\201\000\009\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\063\000\026\000\027\000\028\000\029\000\030\000\
\031\000\032\000\033\000\202\000\203\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\204\000\205\000\206\000\000\000\000\000\207\000\208\000\000\000\
\000\000\209\000\210\000\000\000\000\000\000\000\211\000\212\000\
\000\000\213\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\035\000\036\000\037\000\038\000\189\000\
\040\000\084\000\085\000\006\000\214\000\000\000\215\000\216\000\
\041\000\008\000\042\000\111\001\009\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\063\000\026\000\027\000\028\000\
\029\000\030\000\031\000\032\000\033\000\000\000\000\000\000\000\
\111\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\111\001\111\001\111\001\111\001\111\001\
\111\001\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
\000\000\111\001\111\001\111\001\000\000\111\001\111\001\111\001\
\111\001\000\000\000\000\111\001\000\000\190\000\000\000\111\001\
\111\001\000\000\111\001\111\001\111\001\000\000\111\001\000\000\
\000\000\000\000\000\000\111\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\035\000\036\000\037\000\
\038\000\000\000\040\000\000\000\111\001\111\001\000\000\000\000\
\000\000\000\000\041\000\111\000\042\000\000\000\111\000\111\000\
\111\001\000\000\111\000\111\000\111\000\000\000\000\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\111\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\111\000\000\000\
\111\000\111\000\111\000\000\000\111\000\111\000\111\000\111\000\
\111\000\111\000\111\000\111\000\111\000\000\000\111\000\111\000\
\111\000\111\000\111\000\111\000\111\000\111\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\109\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\111\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\111\000\000\000\111\000\109\000\000\000\111\000\
\109\000\109\000\000\000\000\000\109\000\109\000\109\000\000\000\
\000\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\109\000\000\000\109\000\109\000\109\000\000\000\109\000\109\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\000\000\
\109\000\109\000\109\000\109\000\109\000\109\000\109\000\109\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\135\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\109\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\109\000\000\000\109\000\135\000\
\000\000\109\000\135\000\135\000\000\000\000\000\135\000\135\000\
\135\000\000\000\000\000\135\000\135\000\135\000\135\000\135\000\
\135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
\135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
\135\000\135\000\135\000\000\000\135\000\135\000\135\000\000\000\
\135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
\135\000\000\000\135\000\135\000\135\000\135\000\135\000\135\000\
\135\000\135\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\047\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\135\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\135\000\000\000\
\135\000\047\000\000\000\135\000\047\000\047\000\000\000\000\000\
\047\000\047\000\047\000\000\000\000\000\047\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
\000\000\000\000\047\000\047\000\047\000\047\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\000\000\047\000\047\000\
\047\000\000\000\047\000\047\000\047\000\047\000\000\000\000\000\
\047\000\000\000\047\000\000\000\000\000\047\000\047\000\047\000\
\047\000\047\000\047\000\047\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\049\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\047\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\047\000\000\000\047\000\049\000\000\000\047\000\049\000\049\000\
\000\000\000\000\049\000\049\000\049\000\000\000\000\000\049\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
\049\000\049\000\000\000\000\000\049\000\049\000\049\000\049\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\000\000\
\049\000\049\000\049\000\000\000\049\000\049\000\049\000\049\000\
\000\000\000\000\049\000\000\000\049\000\000\000\000\000\049\000\
\049\000\049\000\049\000\049\000\049\000\049\000\207\002\166\001\
\000\000\153\002\000\000\065\002\197\000\198\000\199\000\200\000\
\069\000\083\000\201\000\000\000\000\000\049\000\000\000\000\000\
\000\000\000\000\000\000\000\000\036\001\000\000\000\000\000\000\
\000\000\000\000\049\000\000\000\049\000\166\001\000\000\049\000\
\000\000\000\000\166\001\000\000\202\000\203\000\000\000\166\001\
\000\000\166\001\166\001\166\001\037\001\166\001\000\000\038\001\
\039\001\000\000\000\000\031\000\032\000\040\001\000\000\000\000\
\000\000\204\000\205\000\206\000\000\000\000\000\207\000\208\000\
\000\000\000\000\209\000\210\000\000\000\000\000\000\000\211\000\
\212\000\000\000\213\000\000\000\148\000\000\000\000\000\166\001\
\000\000\155\002\000\000\000\000\000\000\156\002\157\002\158\002\
\159\002\160\002\161\002\162\002\100\002\000\000\102\001\163\002\
\164\002\102\001\102\001\102\001\102\001\000\000\000\000\000\000\
\165\002\000\000\084\000\085\000\000\000\214\000\000\000\215\000\
\216\000\000\000\166\002\000\000\000\000\102\001\035\000\000\000\
\102\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\102\001\000\000\041\000\000\000\042\000\000\000\000\000\
\000\000\000\000\000\000\000\000\102\001\102\001\102\001\102\001\
\102\001\102\001\102\001\102\001\102\001\102\001\102\001\102\001\
\102\001\000\000\102\001\102\001\102\001\000\000\102\001\102\001\
\102\001\102\001\000\000\000\000\102\001\020\000\000\000\000\000\
\102\001\102\001\000\000\102\001\102\001\102\001\000\000\102\001\
\000\000\000\000\000\000\000\000\103\001\000\000\102\001\103\001\
\103\001\103\001\103\001\000\000\000\000\000\000\000\000\000\000\
\036\001\000\000\000\000\000\000\000\000\102\001\102\001\000\000\
\000\000\000\000\000\000\103\001\000\000\000\000\103\001\000\000\
\000\000\102\001\000\000\000\000\000\000\000\000\000\000\103\001\
\037\001\000\000\000\000\038\001\039\001\000\000\000\000\031\000\
\032\000\040\001\103\001\103\001\103\001\103\001\103\001\103\001\
\103\001\103\001\103\001\103\001\103\001\103\001\103\001\000\000\
\103\001\103\001\103\001\000\000\103\001\103\001\103\001\103\001\
\000\000\000\000\103\001\021\000\000\000\000\000\103\001\103\001\
\000\000\103\001\103\001\103\001\000\000\103\001\000\000\000\000\
\217\001\000\000\108\001\218\001\103\001\108\001\108\001\108\001\
\108\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\103\001\103\001\000\000\000\000\000\000\
\000\000\108\001\035\000\000\000\108\001\000\000\219\001\103\001\
\000\000\000\000\000\000\000\000\000\000\108\001\000\000\041\000\
\000\000\042\000\000\000\000\000\000\000\000\000\000\000\000\000\
\108\001\108\001\108\001\108\001\108\001\108\001\108\001\108\001\
\108\001\108\001\108\001\108\001\108\001\000\000\108\001\108\001\
\108\001\000\000\108\001\108\001\108\001\108\001\000\000\000\000\
\108\001\000\000\000\000\000\000\108\001\108\001\000\000\108\001\
\108\001\108\001\000\000\108\001\000\000\000\000\000\000\000\000\
\000\000\000\000\108\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\108\001\108\001\000\000\000\000\006\000\000\000\000\000\
\000\000\000\000\000\000\008\000\000\000\108\001\009\000\010\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\063\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\033\000\096\000\
\000\000\000\000\097\000\098\000\099\000\083\000\164\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\100\000\000\000\
\000\000\101\000\000\000\000\000\000\000\000\000\000\000\000\000\
\102\000\103\000\000\000\164\001\164\001\000\000\000\000\000\000\
\000\000\164\001\000\000\000\000\177\000\000\000\164\001\000\000\
\164\001\164\001\164\001\000\000\164\001\104\000\105\000\106\000\
\000\000\000\000\107\000\108\000\000\000\000\000\109\000\035\000\
\036\000\037\000\038\000\000\000\040\000\000\000\110\000\000\000\
\000\000\000\000\000\000\000\000\041\000\000\000\042\000\043\000\
\044\000\000\000\000\000\000\000\000\000\000\000\164\001\111\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\084\000\085\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\112\000\006\000\196\000\197\000\198\000\199\000\
\200\000\008\000\083\000\201\000\009\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\063\000\026\000\027\000\028\000\
\029\000\030\000\031\000\032\000\033\000\202\000\203\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\204\000\205\000\206\000\000\000\000\000\207\000\
\208\000\000\000\000\000\209\000\210\000\000\000\000\000\000\000\
\211\000\212\000\000\000\213\000\000\000\148\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\035\000\036\000\037\000\
\000\000\000\000\040\000\084\000\085\000\000\000\214\000\000\000\
\215\000\216\000\041\000\000\000\042\000\006\000\196\000\197\000\
\198\000\199\000\200\000\008\000\083\000\201\000\009\000\010\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\063\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\033\000\202\000\
\203\000\000\000\000\000\165\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\204\000\205\000\206\000\000\000\
\000\000\207\000\208\000\000\000\000\000\209\000\210\000\000\000\
\165\001\165\001\211\000\212\000\000\000\213\000\165\001\000\000\
\000\000\000\000\000\000\165\001\000\000\165\001\165\001\165\001\
\000\000\165\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\035\000\
\036\000\037\000\000\000\000\000\040\000\084\000\085\000\000\000\
\214\000\000\000\215\000\216\000\041\000\000\000\042\000\000\001\
\000\001\000\000\000\000\165\001\000\000\000\001\000\000\161\001\
\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\
\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\
\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\
\000\001\161\001\161\001\000\000\161\001\161\001\000\000\000\000\
\000\000\000\000\161\001\000\000\000\000\000\000\000\000\161\001\
\000\000\161\001\161\001\161\001\000\000\161\001\000\000\000\000\
\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\001\000\001\
\000\000\000\000\000\001\000\000\000\001\000\000\000\001\000\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\161\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\001\000\001\000\001\000\000\000\000\000\001\000\000\
\000\000\245\000\245\000\000\000\000\000\000\000\000\001\245\000\
\000\001\162\001\245\000\245\000\245\000\245\000\245\000\245\000\
\245\000\245\000\245\000\245\000\245\000\245\000\245\000\245\000\
\245\000\245\000\245\000\245\000\245\000\245\000\245\000\245\000\
\245\000\245\000\245\000\162\001\000\000\000\000\162\001\162\001\
\000\000\000\000\000\000\000\000\162\001\000\000\000\000\000\000\
\000\000\162\001\000\000\162\001\162\001\162\001\000\000\162\001\
\000\000\000\000\245\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\245\000\245\000\000\000\000\000\245\000\000\000\245\000\000\000\
\245\000\245\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\162\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\245\000\245\000\245\000\000\000\000\000\
\245\000\000\000\000\000\251\000\251\000\000\000\000\000\000\000\
\245\000\251\000\245\000\163\001\251\000\251\000\251\000\251\000\
\251\000\251\000\251\000\251\000\251\000\251\000\251\000\251\000\
\251\000\251\000\251\000\251\000\251\000\251\000\251\000\251\000\
\251\000\251\000\251\000\251\000\251\000\163\001\000\000\000\000\
\163\001\163\001\000\000\000\000\000\000\000\000\163\001\000\000\
\000\000\000\000\000\000\163\001\000\000\163\001\163\001\163\001\
\000\000\163\001\000\000\000\000\251\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\251\000\251\000\000\000\000\000\251\000\000\000\
\251\000\000\000\251\000\251\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\163\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\251\000\251\000\251\000\
\000\000\000\000\251\000\000\000\000\000\246\000\246\000\000\000\
\000\000\167\001\251\000\246\000\251\000\000\000\246\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\246\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\246\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\246\000\167\001\
\000\000\000\000\000\000\000\000\167\001\000\000\000\000\000\000\
\000\000\167\001\000\000\167\001\167\001\167\001\000\000\167\001\
\000\000\000\000\000\000\000\000\000\000\000\000\246\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\246\000\246\000\000\000\000\000\
\246\000\000\000\246\000\000\000\246\000\246\000\000\000\000\000\
\000\000\167\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\246\000\
\246\000\246\000\000\000\000\000\246\000\000\000\000\000\005\001\
\005\001\000\000\000\000\000\000\246\000\005\001\246\000\000\000\
\005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
\005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
\005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
\005\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\005\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\005\001\
\000\000\000\000\000\000\000\000\021\000\000\000\005\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\005\001\005\001\005\001\000\000\000\000\005\001\000\000\
\000\000\218\000\218\000\000\000\000\000\000\000\005\001\218\000\
\005\001\000\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\000\000\000\000\000\000\000\000\147\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\147\001\147\001\147\001\147\001\
\147\001\147\001\218\000\000\000\000\000\000\000\000\000\000\000\
\147\001\147\001\147\001\000\000\147\001\147\001\147\001\147\001\
\000\000\218\000\147\001\000\000\000\000\000\000\059\000\147\001\
\218\000\147\001\147\001\147\001\000\000\147\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\218\000\218\000\218\000\059\000\000\000\
\218\000\059\000\059\000\000\000\000\000\059\000\059\000\059\000\
\218\000\000\000\218\000\000\000\000\000\000\000\000\000\147\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\059\000\
\059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\059\000\000\000\059\000\059\000\059\000\000\000\059\000\
\059\000\059\000\059\000\000\000\000\000\059\000\000\000\059\000\
\000\000\000\000\059\000\059\000\000\000\059\000\059\000\059\000\
\059\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\059\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\006\000\000\000\000\000\000\000\000\000\059\000\008\000\059\000\
\000\000\009\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\063\000\026\000\027\000\028\000\029\000\030\000\031\000\
\032\000\033\000\006\000\062\000\000\000\000\000\000\000\000\000\
\008\000\000\000\000\000\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\063\000\026\000\027\000\028\000\029\000\
\030\000\031\000\032\000\033\000\000\000\000\000\000\000\000\000\
\164\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\238\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\035\000\036\000\037\000\000\000\000\000\040\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\041\000\
\000\000\042\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\035\000\036\000\037\000\000\000\
\000\000\040\000\000\000\000\000\006\000\000\000\000\000\000\000\
\000\000\041\000\008\000\042\000\000\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\063\000\026\000\027\000\
\028\000\029\000\030\000\031\000\032\000\033\000\006\000\000\000\
\000\000\000\000\000\000\000\000\008\000\000\000\000\000\009\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\063\000\
\026\000\027\000\028\000\029\000\030\000\031\000\032\000\033\000\
\000\000\000\000\000\000\000\000\164\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\035\000\036\000\
\037\000\000\000\000\000\040\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\041\000\000\000\042\000\000\000\237\002\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\035\000\036\000\037\000\000\000\000\000\040\000\000\000\000\000\
\033\001\000\000\000\000\000\000\000\000\041\000\033\001\042\000\
\000\000\033\001\033\001\033\001\033\001\033\001\033\001\033\001\
\033\001\033\001\033\001\033\001\033\001\033\001\033\001\033\001\
\033\001\033\001\033\001\033\001\033\001\033\001\033\001\033\001\
\033\001\033\001\006\000\000\000\000\000\000\000\000\000\000\000\
\008\000\000\000\000\000\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\063\000\026\000\027\000\028\000\029\000\
\030\000\031\000\032\000\033\000\000\000\000\000\000\000\000\000\
\033\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\033\001\033\001\033\001\000\000\000\000\033\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\033\001\
\000\000\033\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\063\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\035\000\036\000\037\000\000\000\
\000\000\040\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\041\000\063\000\042\000\000\000\063\000\063\000\000\000\
\000\000\063\000\063\000\063\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\063\000\063\000\063\000\063\000\063\000\
\063\000\063\000\063\000\000\000\000\000\000\000\000\000\063\000\
\063\000\063\000\000\000\063\000\063\000\063\000\063\000\064\000\
\000\000\063\000\000\000\063\000\000\000\000\000\063\000\063\000\
\000\000\063\000\063\000\063\000\063\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\064\000\
\000\000\000\000\064\000\064\000\063\000\000\000\064\000\064\000\
\064\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\063\000\000\000\063\000\000\000\000\000\000\000\000\000\
\064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
\000\000\000\000\000\000\000\000\064\000\064\000\064\000\000\000\
\064\000\064\000\064\000\064\000\065\000\000\000\064\000\000\000\
\064\000\000\000\000\000\064\000\064\000\000\000\064\000\064\000\
\064\000\064\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\000\000\000\000\065\000\
\065\000\064\000\000\000\065\000\065\000\065\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\064\000\000\000\
\064\000\000\000\000\000\000\000\000\000\065\000\065\000\065\000\
\065\000\065\000\065\000\065\000\065\000\000\000\000\000\000\000\
\000\000\065\000\065\000\065\000\000\000\065\000\065\000\065\000\
\065\000\087\000\000\000\065\000\000\000\065\000\000\000\000\000\
\065\000\065\000\000\000\065\000\065\000\065\000\065\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\087\000\000\000\000\000\087\000\087\000\065\000\000\000\
\087\000\087\000\087\000\000\000\000\000\006\000\000\000\000\000\
\000\000\000\000\000\000\065\000\000\000\065\000\009\000\010\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\063\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\033\000\000\000\
\087\000\000\000\087\000\000\000\000\000\087\000\087\000\000\000\
\087\000\087\000\087\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\066\000\000\000\000\000\000\000\
\000\000\000\000\000\000\087\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\087\000\000\000\087\000\000\000\066\000\000\000\000\000\066\000\
\066\000\000\000\000\000\066\000\066\000\066\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\035\000\
\036\000\037\000\000\000\000\000\040\000\066\000\066\000\066\000\
\066\000\066\000\066\000\000\000\041\000\000\000\042\000\000\000\
\000\000\066\000\066\000\066\000\000\000\066\000\066\000\066\000\
\066\000\067\000\000\000\066\000\000\000\066\000\000\000\000\000\
\066\000\066\000\000\000\066\000\066\000\066\000\066\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\067\000\000\000\000\000\067\000\067\000\066\000\000\000\
\067\000\067\000\067\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\066\000\000\000\066\000\000\000\000\000\
\000\000\000\000\067\000\067\000\067\000\067\000\067\000\067\000\
\000\000\000\000\000\000\000\000\000\000\000\000\067\000\067\000\
\067\000\000\000\067\000\067\000\067\000\067\000\068\000\000\000\
\067\000\000\000\067\000\000\000\000\000\067\000\067\000\000\000\
\067\000\067\000\067\000\067\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\068\000\000\000\
\000\000\068\000\068\000\067\000\000\000\068\000\068\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\067\000\000\000\067\000\000\000\000\000\000\000\000\000\068\000\
\068\000\068\000\068\000\068\000\068\000\000\000\000\000\000\000\
\000\000\000\000\000\000\068\000\068\000\068\000\000\000\068\000\
\068\000\068\000\068\000\069\000\000\000\068\000\000\000\068\000\
\000\000\000\000\068\000\068\000\000\000\068\000\068\000\068\000\
\068\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\069\000\000\000\000\000\069\000\069\000\
\068\000\000\000\069\000\069\000\069\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\068\000\000\000\068\000\
\000\000\000\000\000\000\000\000\069\000\069\000\069\000\069\000\
\069\000\069\000\000\000\000\000\000\000\000\000\000\000\000\000\
\069\000\069\000\069\000\000\000\069\000\069\000\000\000\070\000\
\000\000\000\000\069\000\000\000\069\000\000\000\000\000\069\000\
\069\000\000\000\069\000\069\000\069\000\069\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\070\000\
\000\000\000\000\070\000\070\000\000\000\069\000\070\000\070\000\
\070\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\069\000\000\000\069\000\000\000\000\000\000\000\
\070\000\070\000\070\000\070\000\070\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\070\000\070\000\070\000\000\000\
\070\000\070\000\000\000\071\000\000\000\000\000\070\000\000\000\
\070\000\000\000\000\000\070\000\070\000\000\000\070\000\070\000\
\070\000\070\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\071\000\000\000\000\000\071\000\071\000\
\000\000\070\000\071\000\071\000\071\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\070\000\000\000\
\070\000\000\000\000\000\000\000\071\000\071\000\071\000\071\000\
\071\000\071\000\000\000\000\000\000\000\000\000\000\000\000\000\
\071\000\071\000\071\000\000\000\071\000\071\000\000\000\072\000\
\000\000\000\000\071\000\000\000\071\000\000\000\000\000\071\000\
\071\000\000\000\071\000\071\000\071\000\071\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\072\000\
\000\000\000\000\072\000\072\000\000\000\071\000\072\000\072\000\
\072\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\071\000\000\000\071\000\000\000\000\000\000\000\
\072\000\072\000\072\000\072\000\072\000\072\000\000\000\000\000\
\000\000\000\000\000\000\000\000\072\000\072\000\072\000\000\000\
\072\000\072\000\000\000\073\000\000\000\000\000\072\000\000\000\
\072\000\000\000\000\000\072\000\072\000\000\000\072\000\072\000\
\072\000\072\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\073\000\000\000\000\000\073\000\073\000\
\000\000\072\000\073\000\073\000\073\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\072\000\000\000\
\072\000\000\000\000\000\000\000\073\000\073\000\073\000\073\000\
\073\000\073\000\000\000\000\000\000\000\000\000\074\000\000\000\
\073\000\073\000\073\000\000\000\073\000\073\000\000\000\000\000\
\000\000\000\000\073\000\000\000\073\000\000\000\000\000\073\000\
\073\000\000\000\073\000\073\000\073\000\073\000\074\000\000\000\
\000\000\074\000\074\000\000\000\000\000\074\000\074\000\074\000\
\000\000\000\000\000\000\000\000\000\000\073\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
\074\000\000\000\073\000\000\000\073\000\000\000\000\000\000\000\
\000\000\075\000\000\000\074\000\074\000\074\000\000\000\074\000\
\074\000\000\000\000\000\000\000\000\000\074\000\000\000\074\000\
\000\000\000\000\074\000\074\000\000\000\074\000\074\000\074\000\
\074\000\075\000\000\000\000\000\075\000\075\000\000\000\000\000\
\075\000\075\000\075\000\000\000\000\000\000\000\000\000\000\000\
\074\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\075\000\075\000\000\000\074\000\000\000\074\000\
\000\000\000\000\000\000\000\000\076\000\000\000\075\000\075\000\
\075\000\000\000\075\000\075\000\000\000\000\000\000\000\000\000\
\075\000\000\000\075\000\000\000\000\000\075\000\075\000\000\000\
\075\000\075\000\075\000\075\000\076\000\000\000\000\000\076\000\
\076\000\000\000\000\000\076\000\076\000\076\000\000\000\000\000\
\000\000\000\000\000\000\075\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\076\000\076\000\000\000\
\075\000\000\000\075\000\000\000\000\000\000\000\000\000\077\000\
\000\000\076\000\076\000\076\000\000\000\076\000\076\000\000\000\
\000\000\000\000\000\000\076\000\000\000\076\000\000\000\000\000\
\076\000\076\000\000\000\076\000\076\000\076\000\076\000\077\000\
\000\000\000\000\077\000\077\000\000\000\000\000\077\000\077\000\
\077\000\000\000\000\000\000\000\000\000\000\000\076\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\076\000\000\000\076\000\000\000\000\000\
\000\000\000\000\078\000\000\000\077\000\077\000\077\000\000\000\
\077\000\077\000\000\000\000\000\000\000\000\000\077\000\000\000\
\077\000\000\000\000\000\077\000\077\000\000\000\077\000\077\000\
\077\000\077\000\078\000\000\000\000\000\078\000\078\000\000\000\
\000\000\078\000\078\000\078\000\000\000\000\000\000\000\000\000\
\000\000\077\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\077\000\000\000\
\077\000\000\000\000\000\000\000\000\000\079\000\000\000\078\000\
\078\000\078\000\000\000\078\000\078\000\000\000\000\000\000\000\
\000\000\078\000\000\000\078\000\000\000\000\000\078\000\078\000\
\000\000\078\000\078\000\078\000\078\000\079\000\000\000\000\000\
\079\000\079\000\000\000\000\000\079\000\079\000\079\000\000\000\
\000\000\000\000\000\000\000\000\078\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\078\000\000\000\078\000\000\000\000\000\000\000\000\000\
\080\000\000\000\000\000\079\000\079\000\000\000\079\000\079\000\
\000\000\000\000\000\000\000\000\079\000\000\000\079\000\000\000\
\000\000\079\000\079\000\000\000\079\000\079\000\079\000\079\000\
\080\000\000\000\000\000\080\000\080\000\000\000\000\000\080\000\
\080\000\080\000\000\000\000\000\000\000\000\000\000\000\079\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\079\000\000\000\079\000\000\000\
\000\000\000\000\000\000\081\000\000\000\000\000\080\000\080\000\
\000\000\080\000\080\000\000\000\000\000\000\000\000\000\080\000\
\000\000\080\000\000\000\000\000\080\000\080\000\000\000\080\000\
\080\000\080\000\080\000\081\000\000\000\000\000\081\000\081\000\
\000\000\000\000\081\000\081\000\081\000\000\000\000\000\000\000\
\000\000\000\000\080\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\080\000\
\000\000\080\000\000\000\000\000\000\000\000\000\082\000\000\000\
\000\000\081\000\000\000\000\000\081\000\081\000\000\000\000\000\
\000\000\000\000\081\000\000\000\081\000\000\000\000\000\081\000\
\081\000\000\000\081\000\081\000\081\000\081\000\082\000\000\000\
\000\000\082\000\082\000\000\000\000\000\082\000\082\000\082\000\
\000\000\000\000\000\000\000\000\000\000\081\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\081\000\000\000\081\000\000\000\000\000\000\000\
\000\000\083\000\000\000\000\000\082\000\000\000\000\000\082\000\
\082\000\000\000\000\000\000\000\000\000\082\000\000\000\082\000\
\000\000\000\000\082\000\082\000\000\000\082\000\082\000\082\000\
\082\000\083\000\000\000\000\000\083\000\083\000\000\000\000\000\
\083\000\083\000\083\000\000\000\000\000\000\000\000\000\000\000\
\082\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\082\000\000\000\082\000\
\000\000\000\000\000\000\000\000\084\000\000\000\000\000\000\000\
\000\000\000\000\083\000\083\000\000\000\000\000\000\000\000\000\
\083\000\000\000\083\000\000\000\000\000\083\000\083\000\000\000\
\083\000\083\000\083\000\083\000\084\000\000\000\000\000\084\000\
\084\000\000\000\000\000\084\000\084\000\084\000\000\000\000\000\
\000\000\000\000\000\000\083\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\083\000\000\000\083\000\000\000\000\000\000\000\000\000\085\000\
\000\000\000\000\000\000\000\000\000\000\084\000\084\000\000\000\
\000\000\000\000\000\000\084\000\000\000\084\000\000\000\000\000\
\084\000\084\000\000\000\084\000\084\000\084\000\084\000\085\000\
\000\000\000\000\085\000\085\000\000\000\000\000\085\000\085\000\
\085\000\000\000\000\000\000\000\000\000\000\000\084\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\084\000\000\000\084\000\000\000\000\000\
\000\000\000\000\086\000\000\000\000\000\000\000\000\000\000\000\
\000\000\085\000\000\000\000\000\000\000\000\000\085\000\000\000\
\085\000\000\000\000\000\085\000\085\000\000\000\085\000\085\000\
\085\000\085\000\086\000\000\000\000\000\086\000\086\000\200\000\
\000\000\086\000\086\000\086\000\000\000\000\000\000\000\000\000\
\000\000\085\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\085\000\200\000\
\085\000\000\000\200\000\200\000\000\000\000\000\200\000\200\000\
\200\000\036\001\000\000\200\000\086\000\000\000\000\000\000\000\
\000\000\086\000\000\000\086\000\000\000\000\000\086\000\086\000\
\000\000\086\000\086\000\086\000\086\000\000\000\000\000\000\000\
\000\000\037\001\000\000\000\000\038\001\039\001\000\000\000\000\
\031\000\032\000\040\001\000\000\086\000\000\000\200\000\200\000\
\000\000\200\000\200\000\000\000\200\000\000\000\200\000\200\000\
\000\000\086\000\000\000\086\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\200\000\000\000\000\000\000\000\200\000\000\000\000\000\
\000\000\099\002\000\000\000\000\218\001\000\000\200\000\000\000\
\200\000\000\000\076\001\076\001\076\001\076\001\076\001\076\001\
\076\001\076\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\035\000\000\000\000\000\000\000\219\001\
\000\000\000\000\000\000\076\001\000\000\000\000\000\000\000\000\
\041\000\000\000\042\000\076\001\076\001\076\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\001\076\001\076\001\000\000\000\000\076\001\076\001\000\000\
\000\000\076\001\076\001\000\000\000\000\000\000\076\001\076\001\
\076\001\076\001\000\000\076\001\076\001\076\001\076\001\000\000\
\076\001\076\001\065\002\197\000\198\000\199\000\200\000\069\000\
\083\000\201\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\076\001\076\001\000\000\076\001\000\000\076\001\076\001\
\000\000\000\000\000\000\202\000\203\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\066\002\000\000\000\000\000\000\000\000\000\000\000\000\
\204\000\205\000\206\000\000\000\000\000\207\000\208\000\000\000\
\000\000\209\000\210\000\000\000\000\000\000\000\211\000\212\000\
\000\000\213\000\000\000\213\001\067\002\000\000\000\000\076\001\
\076\001\076\001\076\001\076\001\000\000\076\001\076\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\001\084\000\085\000\000\000\214\000\000\000\215\000\216\000\
\076\001\076\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\076\001\076\001\076\001\
\000\000\000\000\076\001\076\001\000\000\000\000\076\001\076\001\
\000\000\000\000\000\000\076\001\076\001\000\000\076\001\000\000\
\000\000\000\000\076\001\000\000\132\000\132\000\132\000\132\000\
\132\000\000\000\132\000\132\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\076\001\076\001\
\000\000\076\001\000\000\076\001\076\001\132\000\132\000\132\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\132\000\132\000\132\000\000\000\000\000\132\000\
\132\000\000\000\000\000\132\000\132\000\000\000\000\000\000\000\
\132\000\132\000\000\000\132\000\150\001\132\000\000\000\000\000\
\000\000\196\000\197\000\198\000\199\000\200\000\000\000\083\000\
\201\000\150\001\150\001\150\001\150\001\150\001\150\001\000\000\
\000\000\000\000\000\000\000\000\000\000\150\001\150\001\150\001\
\000\000\150\001\150\001\132\000\132\000\000\000\132\000\150\001\
\132\000\132\000\202\000\203\000\150\001\000\000\150\001\150\001\
\150\001\000\000\150\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\204\000\
\205\000\206\000\000\000\000\000\207\000\208\000\000\000\000\000\
\209\000\210\000\000\000\000\000\000\000\211\000\212\000\000\000\
\213\000\151\001\213\001\000\000\150\001\000\000\196\000\197\000\
\198\000\199\000\200\000\000\000\083\000\201\000\151\001\151\001\
\151\001\151\001\151\001\151\001\000\000\000\000\000\000\000\000\
\000\000\000\000\151\001\151\001\151\001\000\000\151\001\151\001\
\084\000\085\000\000\000\214\000\151\001\215\000\216\000\202\000\
\203\000\151\001\000\000\151\001\151\001\151\001\000\000\151\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\204\000\205\000\206\000\000\000\
\000\000\207\000\208\000\000\000\000\000\209\000\210\000\000\000\
\000\000\000\000\211\000\212\000\000\000\213\000\152\001\117\002\
\000\000\151\001\000\000\196\000\197\000\198\000\199\000\200\000\
\000\000\083\000\201\000\152\001\152\001\152\001\152\001\152\001\
\152\001\000\000\000\000\000\000\000\000\000\000\000\000\152\001\
\152\001\152\001\000\000\152\001\152\001\084\000\085\000\000\000\
\214\000\152\001\215\000\216\000\202\000\203\000\152\001\000\000\
\152\001\152\001\152\001\000\000\152\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\204\000\205\000\206\000\000\000\000\000\207\000\208\000\
\000\000\000\000\209\000\210\000\000\000\000\000\000\000\211\000\
\212\000\000\000\213\000\000\000\000\000\000\000\152\001\000\000\
\000\000\215\002\076\001\076\001\076\001\076\001\076\001\000\000\
\076\001\076\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\084\000\085\000\000\000\214\000\000\000\215\000\
\216\000\000\000\000\000\076\001\076\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\001\076\001\076\001\000\000\000\000\076\001\076\001\000\000\
\000\000\076\001\076\001\000\000\000\000\000\000\076\001\076\001\
\000\000\076\001\153\001\000\000\000\000\076\001\000\000\128\000\
\128\000\128\000\128\000\128\000\000\000\128\000\128\000\153\001\
\153\001\153\001\153\001\153\001\153\001\000\000\000\000\000\000\
\000\000\000\000\000\000\153\001\153\001\153\001\000\000\153\001\
\153\001\076\001\076\001\000\000\076\001\153\001\076\001\076\001\
\128\000\128\000\153\001\000\000\153\001\153\001\153\001\000\000\
\153\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\128\000\128\000\128\000\
\000\000\000\000\128\000\128\000\000\000\000\000\128\000\128\000\
\000\000\000\000\000\000\128\000\128\000\000\000\128\000\000\000\
\128\000\000\000\153\001\000\000\077\001\077\001\077\001\077\001\
\077\001\000\000\077\001\077\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\196\000\197\000\
\198\000\199\000\200\000\000\000\083\000\201\000\128\000\128\000\
\000\000\128\000\000\000\128\000\128\000\077\001\077\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\202\000\
\203\000\000\000\077\001\077\001\077\001\000\000\000\000\077\001\
\077\001\000\000\000\000\077\001\077\001\000\000\000\000\000\000\
\077\001\077\001\000\000\077\001\204\000\205\000\206\000\077\001\
\000\000\207\000\208\000\000\000\000\000\209\000\210\000\000\000\
\000\000\000\000\211\000\212\000\000\000\213\000\000\000\000\000\
\000\000\000\000\000\000\196\000\197\000\198\000\199\000\200\000\
\000\000\083\000\201\000\077\001\077\001\000\000\077\001\000\000\
\077\001\077\001\000\000\000\000\000\000\196\000\197\000\198\000\
\199\000\200\000\000\000\083\000\201\000\084\000\085\000\000\000\
\214\000\000\000\215\000\216\000\202\000\203\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\202\000\203\000\
\000\000\204\000\205\000\206\000\000\000\000\000\207\000\208\000\
\000\000\000\000\209\000\210\000\000\000\000\000\000\000\211\000\
\212\000\000\000\246\000\204\000\205\000\206\000\000\000\000\000\
\207\000\208\000\000\000\000\000\209\000\210\000\000\000\000\000\
\000\000\211\000\212\000\000\000\248\000\000\000\000\000\000\000\
\000\000\000\000\196\000\197\000\198\000\199\000\200\000\000\000\
\083\000\201\000\084\000\085\000\000\000\214\000\000\000\215\000\
\216\000\000\000\000\000\000\000\196\000\197\000\198\000\199\000\
\200\000\000\000\083\000\201\000\084\000\085\000\000\000\214\000\
\000\000\215\000\216\000\202\000\203\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\202\000\203\000\000\000\
\204\000\205\000\206\000\000\000\000\000\207\000\208\000\000\000\
\000\000\209\000\210\000\000\000\000\000\000\000\211\000\212\000\
\000\000\107\001\204\000\205\000\206\000\000\000\000\000\207\000\
\208\000\000\000\000\000\209\000\210\000\000\000\000\000\000\000\
\211\000\212\000\000\000\109\001\000\000\000\000\000\000\000\000\
\000\000\196\000\197\000\198\000\199\000\200\000\000\000\083\000\
\201\000\084\000\085\000\000\000\214\000\000\000\215\000\216\000\
\000\000\000\000\000\000\076\001\076\001\076\001\076\001\076\001\
\000\000\076\001\076\001\084\000\085\000\000\000\214\000\000\000\
\215\000\216\000\202\000\203\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\076\001\076\001\000\000\204\000\
\205\000\206\000\000\000\000\000\207\000\208\000\000\000\000\000\
\209\000\210\000\000\000\000\000\000\000\211\000\212\000\000\000\
\118\001\076\001\076\001\076\001\000\000\000\000\076\001\076\001\
\000\000\000\000\076\001\076\001\000\000\000\000\000\000\076\001\
\076\001\000\000\076\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\084\000\085\000\000\000\214\000\096\000\215\000\216\000\097\000\
\098\000\099\000\083\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\076\001\076\001\000\000\076\001\000\000\076\001\
\076\001\000\000\000\000\100\000\096\000\000\000\101\000\097\000\
\098\000\099\000\083\000\000\000\000\000\102\000\103\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\100\000\000\000\000\000\101\000\000\000\
\000\000\000\000\104\000\105\000\106\000\102\000\103\000\107\000\
\108\000\000\000\000\000\109\000\000\000\000\000\000\000\000\000\
\000\000\000\000\180\001\110\000\000\000\000\000\000\000\000\000\
\000\000\000\000\104\000\105\000\106\000\000\000\000\000\107\000\
\108\000\000\000\000\000\109\000\111\000\000\000\000\000\000\000\
\000\000\000\000\000\000\110\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\084\000\085\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\111\000\000\000\000\000\000\000\
\000\000\000\000\118\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\084\000\085\000\118\001\118\001\118\001\
\118\001\118\001\118\001\118\001\118\001\118\001\118\001\118\001\
\118\001\118\001\000\000\118\001\118\001\118\001\000\000\118\001\
\118\001\118\001\118\001\000\000\000\000\118\001\000\000\000\000\
\000\000\118\001\118\001\000\000\118\001\118\001\118\001\000\000\
\118\001\113\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\113\001\113\001\113\001\113\001\
\113\001\113\001\113\001\113\001\113\001\113\001\113\001\113\001\
\113\001\000\000\113\001\113\001\113\001\000\000\113\001\113\001\
\113\001\113\001\118\001\000\000\113\001\000\000\000\000\000\000\
\113\001\113\001\000\000\113\001\113\001\113\001\000\000\113\001\
\114\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\114\001\114\001\114\001\114\001\114\001\
\114\001\114\001\114\001\114\001\114\001\114\001\114\001\114\001\
\000\000\114\001\114\001\114\001\000\000\114\001\114\001\114\001\
\114\001\113\001\000\000\114\001\000\000\000\000\000\000\114\001\
\114\001\128\001\114\001\114\001\114\001\000\000\114\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\128\001\128\001\
\128\001\128\001\128\001\128\001\128\001\128\001\128\001\128\001\
\128\001\000\000\128\001\128\001\128\001\000\000\128\001\128\001\
\128\001\128\001\000\000\000\000\128\001\000\000\000\000\000\000\
\114\001\128\001\130\001\128\001\128\001\128\001\000\000\128\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\130\001\
\130\001\130\001\130\001\130\001\130\001\130\001\130\001\130\001\
\130\001\130\001\000\000\130\001\130\001\130\001\000\000\130\001\
\130\001\130\001\130\001\000\000\000\000\130\001\000\000\000\000\
\000\000\128\001\130\001\132\001\130\001\130\001\130\001\000\000\
\130\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\132\001\132\001\132\001\132\001\132\001\132\001\132\001\132\001\
\132\001\132\001\132\001\000\000\132\001\132\001\132\001\000\000\
\132\001\132\001\132\001\132\001\000\000\000\000\132\001\000\000\
\000\000\000\000\130\001\132\001\144\001\132\001\132\001\132\001\
\000\000\132\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\144\001\144\001\144\001\144\001\144\001\144\001\144\001\
\144\001\000\000\000\000\000\000\000\000\144\001\144\001\144\001\
\000\000\144\001\144\001\144\001\144\001\000\000\000\000\144\001\
\000\000\000\000\000\000\132\001\144\001\145\001\144\001\144\001\
\144\001\000\000\144\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\145\001\145\001\145\001\145\001\145\001\145\001\
\145\001\145\001\000\000\000\000\000\000\000\000\145\001\145\001\
\145\001\000\000\145\001\145\001\145\001\145\001\000\000\000\000\
\145\001\000\000\000\000\000\000\144\001\145\001\146\001\145\001\
\145\001\145\001\000\000\145\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\146\001\146\001\146\001\146\001\146\001\
\146\001\146\001\146\001\000\000\000\000\000\000\000\000\146\001\
\146\001\146\001\000\000\146\001\146\001\146\001\146\001\000\000\
\000\000\146\001\000\000\000\000\000\000\145\001\146\001\148\001\
\146\001\146\001\146\001\000\000\146\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\148\001\148\001\148\001\148\001\
\148\001\148\001\000\000\000\000\000\000\000\000\000\000\000\000\
\148\001\148\001\148\001\000\000\148\001\148\001\148\001\148\001\
\000\000\000\000\148\001\000\000\000\000\000\000\146\001\148\001\
\149\001\148\001\148\001\148\001\000\000\148\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\149\001\149\001\149\001\
\149\001\149\001\149\001\000\000\000\000\000\000\000\000\000\000\
\000\000\149\001\149\001\149\001\000\000\149\001\149\001\149\001\
\149\001\000\000\000\000\149\001\000\000\000\000\000\000\148\001\
\149\001\154\001\149\001\149\001\149\001\000\000\149\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\154\001\154\001\
\154\001\154\001\154\001\154\001\000\000\000\000\000\000\000\000\
\155\001\000\000\154\001\154\001\154\001\000\000\154\001\154\001\
\000\000\000\000\000\000\000\000\154\001\155\001\155\001\000\000\
\149\001\154\001\000\000\154\001\154\001\154\001\000\000\154\001\
\156\001\155\001\155\001\155\001\000\000\155\001\155\001\000\000\
\000\000\000\000\000\000\155\001\000\000\156\001\156\001\000\000\
\155\001\000\000\155\001\155\001\155\001\000\000\155\001\157\001\
\000\000\156\001\156\001\156\001\000\000\156\001\156\001\000\000\
\000\000\154\001\000\000\156\001\157\001\157\001\000\000\000\000\
\156\001\000\000\156\001\156\001\156\001\000\000\156\001\159\001\
\157\001\157\001\157\001\000\000\157\001\157\001\000\000\000\000\
\155\001\000\000\157\001\000\000\000\000\000\000\000\000\157\001\
\000\000\157\001\157\001\157\001\000\000\157\001\000\000\000\000\
\159\001\159\001\159\001\000\000\159\001\159\001\000\000\000\000\
\156\001\000\000\159\001\000\000\000\000\000\000\000\000\159\001\
\000\000\159\001\159\001\159\001\000\000\159\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\157\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\159\001\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\000\000\025\000\025\000\025\000\000\000\025\000\025\000\025\000\
\025\000\025\000\025\000\000\000\025\000\025\000\000\000\025\000\
\000\000\020\000\000\000\025\000\025\000\000\000\025\000"

let yycheck = "\016\000\
\017\000\091\000\019\000\093\000\050\000\056\000\001\000\002\000\
\165\000\046\001\117\000\088\000\194\000\025\000\212\001\072\000\
\164\000\064\000\064\000\035\001\221\001\003\001\001\000\002\000\
\044\000\034\000\048\001\000\000\074\001\230\001\086\002\227\001\
\044\000\001\000\002\000\086\000\004\000\050\000\006\001\034\000\
\049\000\063\001\088\002\011\001\080\000\048\001\157\000\091\002\
\054\000\016\000\017\000\064\000\019\000\165\000\049\000\034\000\
\062\001\114\000\075\000\065\000\173\000\174\000\079\000\077\001\
\006\001\082\000\034\000\079\001\080\001\051\000\049\000\017\000\
\201\000\019\000\079\001\117\002\088\000\056\000\084\001\012\001\
\092\000\049\000\094\000\006\001\241\000\084\001\077\001\025\000\
\056\000\131\002\110\000\059\000\104\000\105\000\106\000\107\000\
\108\000\109\000\110\000\067\000\012\001\152\000\153\000\012\001\
\013\001\117\000\044\000\086\000\075\000\238\000\129\002\079\001\
\079\000\056\000\103\001\082\000\102\000\103\000\086\000\165\000\
\076\001\006\001\077\001\122\001\201\000\093\000\143\000\116\001\
\084\001\241\000\076\000\136\000\178\000\012\001\076\001\103\001\
\012\001\006\001\036\001\037\001\122\001\177\000\011\001\076\001\
\180\000\154\000\182\000\183\000\116\001\082\001\186\000\187\000\
\165\000\076\001\092\000\213\000\094\000\102\002\009\001\154\000\
\206\002\238\000\144\000\145\000\051\000\209\002\104\000\105\000\
\106\000\107\000\108\000\109\000\110\000\152\000\153\000\154\000\
\109\001\110\001\197\002\117\000\072\001\190\000\194\000\043\001\
\152\000\153\000\154\000\047\001\246\000\205\001\248\000\076\001\
\000\000\210\000\226\001\190\000\164\000\109\001\110\001\139\002\
\109\001\110\001\084\001\082\001\079\001\103\001\061\001\213\000\
\077\001\152\000\153\000\190\000\046\001\235\001\236\001\218\001\
\202\000\203\000\116\001\222\001\118\001\189\000\190\000\062\001\
\081\001\211\000\212\000\077\001\241\000\077\001\109\001\110\001\
\235\001\109\001\110\001\247\001\089\002\078\001\178\002\121\001\
\246\000\075\001\248\000\082\001\085\001\213\000\002\001\173\001\
\077\001\083\001\213\000\015\001\013\001\014\001\010\001\077\001\
\194\000\144\000\145\000\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\246\000\035\001\
\248\000\081\003\006\001\246\000\041\001\248\000\076\002\011\001\
\230\002\077\001\076\001\125\001\053\001\074\002\043\001\044\001\
\082\001\082\001\047\001\048\001\062\001\086\001\013\001\014\001\
\084\001\107\001\160\002\109\001\099\001\163\002\071\001\091\001\
\088\002\089\002\094\001\168\002\118\001\170\002\098\001\172\002\
\002\001\076\001\084\001\006\001\126\001\127\001\006\001\088\001\
\010\001\077\001\085\001\011\001\183\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\133\002\035\001\066\001\079\001\146\002\107\001\218\001\109\001\
\072\001\078\001\217\001\052\001\053\001\079\001\006\001\127\002\
\118\001\130\001\131\001\011\001\006\001\129\001\234\001\079\001\
\236\001\011\001\232\002\213\001\104\000\105\000\106\000\107\000\
\108\000\109\000\029\001\016\003\082\001\032\001\082\001\080\001\
\168\002\006\001\170\002\107\001\172\002\109\001\011\001\079\001\
\107\001\029\001\109\001\006\001\032\001\006\001\118\001\036\003\
\011\001\007\003\011\001\118\001\041\001\006\001\126\001\127\001\
\250\001\173\001\011\001\130\001\131\001\077\001\062\001\103\001\
\225\001\066\001\216\001\134\001\135\001\068\001\206\002\060\003\
\102\001\070\001\006\001\033\003\116\001\009\001\010\001\011\001\
\012\001\231\001\067\001\006\001\041\001\079\001\062\001\129\001\
\011\001\205\001\079\001\055\002\213\001\098\002\124\001\084\001\
\085\001\029\001\085\001\166\001\032\001\251\001\090\001\212\001\
\077\001\084\001\082\001\080\001\084\001\218\001\006\001\053\001\
\252\001\222\001\078\002\011\001\079\001\081\002\079\001\005\001\
\218\002\126\002\220\002\221\002\077\001\234\001\235\001\236\001\
\006\001\067\002\111\001\173\001\006\001\011\001\076\001\233\002\
\074\002\011\001\080\001\062\001\103\001\062\001\213\001\029\001\
\108\002\031\001\032\001\033\001\053\001\221\001\036\001\037\001\
\038\001\116\001\077\001\227\001\077\001\080\001\230\001\080\001\
\071\001\003\003\094\001\205\001\006\001\041\001\001\000\002\000\
\006\001\011\001\071\001\013\003\014\003\011\001\076\001\080\001\
\087\001\109\001\110\001\117\002\082\001\023\003\024\003\079\001\
\062\001\076\001\087\001\041\001\016\001\017\001\018\001\082\001\
\091\002\131\002\077\001\133\002\038\003\080\001\009\002\077\001\
\076\001\066\002\055\002\077\001\098\002\081\001\006\001\083\001\
\084\001\085\001\063\002\011\001\084\001\119\002\120\002\060\001\
\061\001\103\001\085\001\061\003\062\001\086\002\082\002\161\002\
\062\001\078\002\091\002\076\001\081\002\076\001\116\001\080\001\
\118\001\062\001\076\003\077\001\085\001\098\002\076\001\077\001\
\204\002\006\001\080\001\076\001\082\001\121\001\084\001\085\001\
\091\002\006\001\085\001\066\002\117\002\041\001\011\001\108\002\
\121\002\079\001\006\001\085\001\198\002\009\001\010\001\011\001\
\091\002\126\002\131\002\127\002\079\002\076\001\077\001\072\001\
\073\001\080\001\079\001\091\002\076\001\077\001\085\001\084\001\
\080\001\029\001\078\001\177\002\032\001\085\001\102\002\152\002\
\079\001\081\001\076\001\084\001\103\002\158\002\086\001\081\001\
\082\002\062\001\084\001\085\001\054\001\055\001\117\002\119\002\
\120\002\078\001\121\002\079\001\079\001\078\001\164\002\076\001\
\077\001\084\001\085\001\080\001\131\002\082\001\076\001\084\001\
\085\001\077\001\004\003\139\002\060\001\061\001\095\001\096\001\
\097\001\140\002\072\001\073\001\076\001\005\001\077\001\121\001\
\152\002\081\001\082\001\077\001\084\001\127\002\207\002\066\001\
\209\002\067\001\094\001\006\001\159\002\054\001\055\001\204\002\
\011\001\218\002\123\001\220\002\221\002\029\001\084\001\085\001\
\032\001\033\001\178\002\070\001\036\001\037\001\038\001\068\001\
\233\002\006\001\062\001\063\001\064\001\016\003\011\001\100\001\
\101\001\230\002\204\000\205\000\206\000\207\000\208\000\209\000\
\121\001\056\001\057\001\058\001\059\001\062\001\063\001\064\001\
\203\002\075\003\003\003\056\001\057\001\058\001\059\001\095\001\
\096\001\097\001\213\002\062\001\013\003\014\003\217\002\076\001\
\012\003\085\001\008\003\095\001\096\001\097\001\023\003\024\003\
\041\001\076\001\077\001\084\001\085\001\080\001\084\001\085\001\
\028\003\029\003\085\001\076\001\026\003\038\003\076\001\103\001\
\152\000\153\000\076\001\107\001\009\001\248\002\076\001\076\001\
\077\001\052\001\053\001\080\001\116\001\016\003\118\001\005\001\
\085\001\151\001\152\001\076\001\061\003\057\003\079\001\009\001\
\016\003\082\001\005\001\084\001\085\001\016\003\113\001\074\001\
\075\001\122\001\077\001\076\003\076\001\080\001\006\001\029\001\
\081\003\077\003\032\001\033\001\153\001\154\001\036\001\037\001\
\038\001\036\003\029\001\087\003\077\001\032\001\033\001\028\003\
\029\003\036\001\037\001\038\001\159\001\160\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\060\003\078\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\063\001\064\001\041\001\066\001\
\067\001\068\001\082\001\070\001\071\001\072\001\073\001\057\003\
\076\001\076\001\076\001\078\001\144\000\145\000\081\001\082\001\
\083\001\084\001\085\001\086\001\087\001\155\001\156\001\157\001\
\158\001\103\001\085\001\077\003\023\001\024\001\025\001\026\001\
\084\001\076\001\019\001\020\001\103\001\087\003\116\001\082\001\
\118\001\084\001\085\001\223\002\224\002\225\002\078\001\006\001\
\078\001\116\001\078\001\118\001\011\001\078\001\121\001\021\001\
\022\001\078\001\148\001\149\001\150\001\151\001\152\001\153\001\
\154\001\155\001\156\001\157\001\158\001\159\001\160\001\161\001\
\162\001\163\001\164\001\165\001\001\001\076\001\003\001\004\001\
\005\001\006\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\085\001\076\001\077\001\027\001\
\028\001\080\001\076\001\076\001\076\001\076\001\085\001\084\001\
\077\001\076\001\085\001\081\001\077\001\081\001\078\001\060\001\
\061\001\062\001\084\001\078\001\065\001\066\001\085\001\084\001\
\069\001\070\001\080\001\078\001\078\001\074\001\075\001\079\001\
\077\001\078\001\079\001\076\001\076\001\076\001\085\001\084\001\
\076\001\085\001\085\001\088\001\089\001\090\001\091\001\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\099\001\076\001\
\082\001\011\002\103\001\104\001\105\001\106\001\107\001\108\001\
\109\001\110\001\083\001\112\001\041\001\114\001\115\001\116\001\
\117\001\118\001\119\001\120\001\085\001\122\001\123\001\124\001\
\082\001\078\001\076\001\076\001\076\001\001\001\081\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\078\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\051\001\076\001\085\001\084\001\076\001\076\001\122\001\031\001\
\060\001\061\001\062\001\078\001\076\001\065\001\066\001\123\001\
\084\001\069\001\070\001\084\001\077\001\082\001\074\001\075\001\
\084\001\077\001\078\001\079\001\082\001\123\001\076\001\076\001\
\084\001\081\001\078\001\125\002\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\099\001\
\077\001\076\001\076\001\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\084\001\112\001\084\001\114\001\115\001\
\116\001\117\001\118\001\119\001\120\001\001\001\122\001\123\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\137\001\138\001\139\001\
\140\001\141\001\142\001\143\001\144\001\145\001\146\001\147\001\
\077\001\077\001\006\001\081\001\084\001\077\001\095\001\076\001\
\060\001\061\001\062\001\082\001\082\001\065\001\066\001\123\001\
\084\001\069\001\070\001\123\001\080\001\076\001\074\001\075\001\
\006\001\077\001\078\001\079\001\084\001\102\001\084\001\076\001\
\084\001\082\001\085\001\081\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\099\001\
\084\001\084\001\077\001\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\076\001\112\001\082\001\114\001\115\001\
\116\001\117\001\118\001\119\001\120\001\001\001\076\001\123\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\085\001\082\001\078\001\
\000\000\084\001\076\001\079\001\076\001\078\001\084\001\078\001\
\078\001\076\001\078\001\080\001\076\001\078\001\076\001\081\001\
\060\001\061\001\062\001\082\001\079\001\065\001\066\001\084\001\
\079\001\069\001\070\001\078\001\084\001\077\001\074\001\075\001\
\084\001\077\001\076\001\079\001\076\001\076\001\076\001\002\000\
\084\001\248\002\189\002\222\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\099\001\
\197\002\076\001\004\000\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\085\002\112\001\209\001\114\001\115\001\
\116\001\117\001\118\001\119\001\120\001\001\001\251\001\123\001\
\041\001\005\001\006\001\143\000\161\001\165\001\125\002\011\001\
\163\001\103\002\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\076\001\162\001\164\001\079\001\063\002\
\239\001\082\001\177\002\084\001\085\001\171\000\042\003\009\001\
\029\001\183\001\030\001\033\001\031\001\087\003\032\001\084\003\
\001\001\255\255\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\064\003\066\003\255\255\103\001\104\001\105\001\106\001\255\255\
\108\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\060\001\061\001\062\001\255\255\123\001\
\065\001\066\001\255\255\255\255\069\001\070\001\255\255\255\255\
\255\255\074\001\075\001\255\255\077\001\078\001\079\001\255\255\
\255\255\255\255\255\255\084\001\255\255\255\255\255\255\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\099\001\255\255\255\255\255\255\103\001\104\001\
\105\001\106\001\107\001\108\001\109\001\110\001\255\255\112\001\
\113\001\114\001\115\001\116\001\117\001\118\001\119\001\120\001\
\001\001\122\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\060\001\061\001\062\001\255\255\255\255\
\065\001\066\001\255\255\255\255\069\001\070\001\255\255\255\255\
\255\255\074\001\075\001\255\255\077\001\078\001\079\001\255\255\
\255\255\255\255\255\255\084\001\255\255\255\255\255\255\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\099\001\255\255\255\255\255\255\103\001\104\001\
\105\001\106\001\107\001\108\001\109\001\110\001\255\255\112\001\
\255\255\114\001\115\001\116\001\117\001\118\001\119\001\120\001\
\001\001\122\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\060\001\061\001\062\001\255\255\255\255\
\065\001\066\001\255\255\255\255\069\001\070\001\255\255\255\255\
\255\255\074\001\075\001\255\255\077\001\255\255\079\001\255\255\
\255\255\255\255\255\255\084\001\255\255\255\255\255\255\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\255\255\255\255\
\255\255\098\001\099\001\255\255\255\255\255\255\103\001\104\001\
\105\001\255\255\107\001\108\001\109\001\110\001\041\001\112\001\
\255\255\114\001\115\001\116\001\117\001\118\001\255\255\255\255\
\001\001\122\001\003\001\004\001\255\255\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\255\255\255\255\066\001\
\067\001\068\001\255\255\070\001\071\001\255\255\255\255\255\255\
\255\255\076\001\255\255\255\255\255\255\255\255\081\001\255\255\
\083\001\084\001\085\001\255\255\087\001\255\255\039\001\040\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\060\001\061\001\062\001\255\255\255\255\
\065\001\066\001\255\255\255\255\069\001\070\001\121\001\255\255\
\255\255\074\001\075\001\255\255\077\001\255\255\079\001\255\255\
\255\255\255\255\255\255\084\001\255\255\255\255\255\255\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\099\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\107\001\255\255\109\001\110\001\255\255\112\001\
\255\255\114\001\115\001\255\255\117\001\255\255\001\001\002\001\
\255\255\122\001\005\001\006\001\255\255\255\255\255\255\255\255\
\011\001\255\255\041\001\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\067\001\068\001\255\255\070\001\
\071\001\255\255\255\255\255\255\255\255\076\001\255\255\255\255\
\255\255\255\255\081\001\255\255\083\001\084\001\085\001\255\255\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\001\001\255\255\003\001\004\001\
\255\255\006\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\084\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\121\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\103\001\104\001\105\001\106\001\
\107\001\108\001\039\001\040\001\255\255\255\255\255\255\255\255\
\255\255\116\001\255\255\118\001\119\001\120\001\255\255\122\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\060\001\
\061\001\062\001\255\255\255\255\065\001\066\001\255\255\255\255\
\069\001\070\001\255\255\255\255\255\255\074\001\075\001\255\255\
\077\001\255\255\079\001\255\255\255\255\255\255\255\255\084\001\
\255\255\255\255\255\255\088\001\089\001\090\001\091\001\092\001\
\093\001\094\001\255\255\255\255\255\255\098\001\099\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\107\001\255\255\
\109\001\110\001\255\255\112\001\255\255\114\001\115\001\001\001\
\117\001\255\255\255\255\005\001\006\001\122\001\255\255\009\001\
\010\001\011\001\255\255\255\255\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\255\255\255\255\041\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\064\001\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\255\255\255\255\076\001\077\001\255\255\079\001\080\001\081\001\
\082\001\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\094\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\103\001\104\001\105\001\
\106\001\255\255\108\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\001\001\255\255\121\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\078\001\079\001\255\255\255\255\255\255\255\255\
\084\001\255\255\255\255\255\255\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\099\001\
\255\255\255\255\255\255\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\255\255\112\001\255\255\114\001\115\001\
\116\001\117\001\118\001\119\001\120\001\001\001\255\255\255\255\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\255\255\079\001\255\255\255\255\255\255\255\255\
\084\001\255\255\255\255\255\255\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\255\255\255\255\255\255\098\001\099\001\
\255\255\255\255\255\255\103\001\104\001\105\001\106\001\107\001\
\108\001\109\001\110\001\255\255\112\001\255\255\114\001\115\001\
\116\001\117\001\118\001\119\001\120\001\001\001\255\255\255\255\
\255\255\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\104\001\105\001\106\001\001\001\
\108\001\109\001\110\001\005\001\112\001\255\255\114\001\115\001\
\116\001\011\001\118\001\012\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\255\255\255\255\255\255\
\041\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\064\001\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\255\255\255\255\076\001\255\255\079\001\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\255\255\087\001\255\255\
\255\255\255\255\255\255\005\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\103\001\104\001\105\001\
\106\001\255\255\108\001\255\255\109\001\110\001\255\255\255\255\
\255\255\255\255\116\001\029\001\118\001\255\255\032\001\033\001\
\121\001\255\255\036\001\037\001\038\001\255\255\255\255\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\064\001\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\074\001\075\001\076\001\077\001\078\001\255\255\080\001\081\001\
\082\001\083\001\084\001\085\001\086\001\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\103\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\029\001\255\255\121\001\
\032\001\033\001\255\255\255\255\036\001\037\001\038\001\255\255\
\255\255\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\064\001\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\072\001\073\001\074\001\075\001\076\001\077\001\078\001\255\255\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\087\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\005\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\103\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\116\001\255\255\118\001\029\001\
\255\255\121\001\032\001\033\001\255\255\255\255\036\001\037\001\
\038\001\255\255\255\255\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\064\001\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\072\001\073\001\074\001\075\001\076\001\077\001\
\078\001\255\255\080\001\081\001\082\001\083\001\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\103\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\118\001\029\001\255\255\121\001\032\001\033\001\255\255\255\255\
\036\001\037\001\038\001\255\255\255\255\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\050\001\051\001\
\255\255\255\255\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\064\001\255\255\066\001\067\001\
\068\001\255\255\070\001\071\001\072\001\073\001\255\255\255\255\
\076\001\255\255\078\001\255\255\255\255\081\001\082\001\083\001\
\084\001\085\001\086\001\087\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\005\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\029\001\255\255\121\001\032\001\033\001\
\255\255\255\255\036\001\037\001\038\001\255\255\255\255\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\064\001\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\255\255\255\255\076\001\255\255\078\001\255\255\255\255\081\001\
\082\001\083\001\084\001\085\001\086\001\087\001\001\001\041\001\
\255\255\004\001\255\255\006\001\007\001\008\001\009\001\010\001\
\011\001\012\001\013\001\255\255\255\255\103\001\255\255\255\255\
\255\255\255\255\255\255\255\255\005\001\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\071\001\255\255\121\001\
\255\255\255\255\076\001\255\255\039\001\040\001\255\255\081\001\
\255\255\083\001\084\001\085\001\029\001\087\001\255\255\032\001\
\033\001\255\255\255\255\036\001\037\001\038\001\255\255\255\255\
\255\255\060\001\061\001\062\001\255\255\255\255\065\001\066\001\
\255\255\255\255\069\001\070\001\255\255\255\255\255\255\074\001\
\075\001\255\255\077\001\255\255\079\001\255\255\255\255\121\001\
\255\255\084\001\255\255\255\255\255\255\088\001\089\001\090\001\
\091\001\092\001\093\001\094\001\077\001\255\255\006\001\098\001\
\099\001\009\001\010\001\011\001\012\001\255\255\255\255\255\255\
\107\001\255\255\109\001\110\001\255\255\112\001\255\255\114\001\
\115\001\255\255\117\001\255\255\255\255\029\001\103\001\255\255\
\032\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\041\001\255\255\116\001\255\255\118\001\255\255\255\255\
\255\255\255\255\255\255\255\255\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\064\001\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\072\001\073\001\255\255\255\255\076\001\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\255\255\255\255\255\255\255\255\006\001\255\255\094\001\009\001\
\010\001\011\001\012\001\255\255\255\255\255\255\255\255\255\255\
\005\001\255\255\255\255\255\255\255\255\109\001\110\001\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\032\001\255\255\
\255\255\121\001\255\255\255\255\255\255\255\255\255\255\041\001\
\029\001\255\255\255\255\032\001\033\001\255\255\255\255\036\001\
\037\001\038\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\064\001\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\255\255\255\255\076\001\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\077\001\255\255\006\001\080\001\094\001\009\001\010\001\011\001\
\012\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\109\001\110\001\255\255\255\255\255\255\
\255\255\029\001\103\001\255\255\032\001\255\255\107\001\121\001\
\255\255\255\255\255\255\255\255\255\255\041\001\255\255\116\001\
\255\255\118\001\255\255\255\255\255\255\255\255\255\255\255\255\
\052\001\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\064\001\255\255\066\001\067\001\
\068\001\255\255\070\001\071\001\072\001\073\001\255\255\255\255\
\076\001\255\255\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\255\255\087\001\255\255\255\255\255\255\255\255\
\255\255\255\255\094\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\109\001\110\001\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\011\001\255\255\121\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\006\001\
\255\255\255\255\009\001\010\001\011\001\012\001\041\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\029\001\255\255\
\255\255\032\001\255\255\255\255\255\255\255\255\255\255\255\255\
\039\001\040\001\255\255\070\001\071\001\255\255\255\255\255\255\
\255\255\076\001\255\255\255\255\084\001\255\255\081\001\255\255\
\083\001\084\001\085\001\255\255\087\001\060\001\061\001\062\001\
\255\255\255\255\065\001\066\001\255\255\255\255\069\001\103\001\
\104\001\105\001\106\001\255\255\108\001\255\255\077\001\255\255\
\255\255\255\255\255\255\255\255\116\001\255\255\118\001\119\001\
\120\001\255\255\255\255\255\255\255\255\255\255\121\001\094\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\109\001\110\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\121\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\060\001\061\001\062\001\255\255\255\255\065\001\
\066\001\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\074\001\075\001\255\255\077\001\255\255\079\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\103\001\104\001\105\001\
\255\255\255\255\108\001\109\001\110\001\255\255\112\001\255\255\
\114\001\115\001\116\001\255\255\118\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\255\255\255\255\041\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\060\001\061\001\062\001\255\255\
\255\255\065\001\066\001\255\255\255\255\069\001\070\001\255\255\
\070\001\071\001\074\001\075\001\255\255\077\001\076\001\255\255\
\255\255\255\255\255\255\081\001\255\255\083\001\084\001\085\001\
\255\255\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\103\001\
\104\001\105\001\255\255\255\255\108\001\109\001\110\001\255\255\
\112\001\255\255\114\001\115\001\116\001\255\255\118\001\005\001\
\006\001\255\255\255\255\121\001\255\255\011\001\255\255\041\001\
\014\001\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\067\001\068\001\255\255\070\001\071\001\255\255\255\255\
\255\255\255\255\076\001\255\255\255\255\255\255\255\255\081\001\
\255\255\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\062\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\076\001\077\001\
\255\255\255\255\080\001\255\255\082\001\255\255\084\001\085\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\121\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\103\001\104\001\105\001\255\255\255\255\108\001\255\255\
\255\255\005\001\006\001\255\255\255\255\255\255\116\001\011\001\
\118\001\041\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\067\001\255\255\255\255\070\001\071\001\
\255\255\255\255\255\255\255\255\076\001\255\255\255\255\255\255\
\255\255\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\255\255\255\255\062\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\076\001\077\001\255\255\255\255\080\001\255\255\082\001\255\255\
\084\001\085\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\121\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\104\001\105\001\255\255\255\255\
\108\001\255\255\255\255\005\001\006\001\255\255\255\255\255\255\
\116\001\011\001\118\001\041\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\067\001\255\255\255\255\
\070\001\071\001\255\255\255\255\255\255\255\255\076\001\255\255\
\255\255\255\255\255\255\081\001\255\255\083\001\084\001\085\001\
\255\255\087\001\255\255\255\255\062\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\076\001\077\001\255\255\255\255\080\001\255\255\
\082\001\255\255\084\001\085\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\121\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\103\001\104\001\105\001\
\255\255\255\255\108\001\255\255\255\255\005\001\006\001\255\255\
\255\255\041\001\116\001\011\001\118\001\255\255\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\071\001\
\255\255\255\255\255\255\255\255\076\001\255\255\255\255\255\255\
\255\255\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\255\255\255\255\255\255\255\255\255\255\255\255\062\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\076\001\077\001\255\255\255\255\
\080\001\255\255\082\001\255\255\084\001\085\001\255\255\255\255\
\255\255\121\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\103\001\
\104\001\105\001\255\255\255\255\108\001\255\255\255\255\005\001\
\006\001\255\255\255\255\255\255\116\001\011\001\118\001\255\255\
\014\001\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\062\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\077\001\
\255\255\255\255\255\255\255\255\082\001\255\255\084\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\103\001\104\001\105\001\255\255\255\255\108\001\255\255\
\255\255\005\001\006\001\255\255\255\255\255\255\116\001\011\001\
\118\001\255\255\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\041\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\062\001\255\255\255\255\255\255\255\255\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\255\255\077\001\076\001\255\255\255\255\255\255\005\001\081\001\
\084\001\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\104\001\105\001\029\001\255\255\
\108\001\032\001\033\001\255\255\255\255\036\001\037\001\038\001\
\116\001\255\255\118\001\255\255\255\255\255\255\255\255\121\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\064\001\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\072\001\073\001\255\255\255\255\076\001\255\255\078\001\
\255\255\255\255\081\001\082\001\255\255\084\001\085\001\086\001\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\103\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\005\001\255\255\255\255\255\255\255\255\116\001\011\001\118\001\
\255\255\014\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\005\001\006\001\255\255\255\255\255\255\255\255\
\011\001\255\255\255\255\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\255\255\255\255\255\255\255\255\
\077\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\086\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\103\001\104\001\105\001\255\255\255\255\108\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\116\001\
\255\255\118\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\103\001\104\001\105\001\255\255\
\255\255\108\001\255\255\255\255\005\001\255\255\255\255\255\255\
\255\255\116\001\011\001\118\001\255\255\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\005\001\255\255\
\255\255\255\255\255\255\255\255\011\001\255\255\255\255\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\255\255\255\255\255\255\255\255\077\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\103\001\104\001\
\105\001\255\255\255\255\108\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\118\001\255\255\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\103\001\104\001\105\001\255\255\255\255\108\001\255\255\255\255\
\005\001\255\255\255\255\255\255\255\255\116\001\011\001\118\001\
\255\255\014\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\005\001\255\255\255\255\255\255\255\255\255\255\
\011\001\255\255\255\255\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\032\001\033\001\034\001\
\035\001\036\001\037\001\038\001\255\255\255\255\255\255\255\255\
\077\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\103\001\104\001\105\001\255\255\255\255\108\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\116\001\
\255\255\118\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\005\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\103\001\104\001\105\001\255\255\
\255\255\108\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\116\001\029\001\118\001\255\255\032\001\033\001\255\255\
\255\255\036\001\037\001\038\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\255\255\255\255\255\255\255\255\066\001\
\067\001\068\001\255\255\070\001\071\001\072\001\073\001\005\001\
\255\255\076\001\255\255\078\001\255\255\255\255\081\001\082\001\
\255\255\084\001\085\001\086\001\087\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\029\001\
\255\255\255\255\032\001\033\001\103\001\255\255\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\116\001\255\255\118\001\255\255\255\255\255\255\255\255\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\255\255\255\255\255\255\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\072\001\073\001\005\001\255\255\076\001\255\255\
\078\001\255\255\255\255\081\001\082\001\255\255\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\029\001\255\255\255\255\032\001\
\033\001\103\001\255\255\036\001\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\118\001\255\255\255\255\255\255\255\255\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\255\255\255\255\255\255\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\005\001\255\255\076\001\255\255\078\001\255\255\255\255\
\081\001\082\001\255\255\084\001\085\001\086\001\087\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\029\001\255\255\255\255\032\001\033\001\103\001\255\255\
\036\001\037\001\038\001\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\118\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\255\255\
\076\001\255\255\078\001\255\255\255\255\081\001\082\001\255\255\
\084\001\085\001\086\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\005\001\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\255\255\029\001\255\255\255\255\032\001\
\033\001\255\255\255\255\036\001\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\103\001\
\104\001\105\001\255\255\255\255\108\001\054\001\055\001\056\001\
\057\001\058\001\059\001\255\255\116\001\255\255\118\001\255\255\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\005\001\255\255\076\001\255\255\078\001\255\255\255\255\
\081\001\082\001\255\255\084\001\085\001\086\001\087\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\029\001\255\255\255\255\032\001\033\001\103\001\255\255\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\118\001\255\255\255\255\
\255\255\255\255\054\001\055\001\056\001\057\001\058\001\059\001\
\255\255\255\255\255\255\255\255\255\255\255\255\066\001\067\001\
\068\001\255\255\070\001\071\001\072\001\073\001\005\001\255\255\
\076\001\255\255\078\001\255\255\255\255\081\001\082\001\255\255\
\084\001\085\001\086\001\087\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\029\001\255\255\
\255\255\032\001\033\001\103\001\255\255\036\001\037\001\038\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\255\255\255\255\255\255\255\255\054\001\
\055\001\056\001\057\001\058\001\059\001\255\255\255\255\255\255\
\255\255\255\255\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\072\001\073\001\005\001\255\255\076\001\255\255\078\001\
\255\255\255\255\081\001\082\001\255\255\084\001\085\001\086\001\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\032\001\033\001\
\103\001\255\255\036\001\037\001\038\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\116\001\255\255\118\001\
\255\255\255\255\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\255\255\255\255\255\255\255\255\255\255\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\255\255\005\001\
\255\255\255\255\076\001\255\255\078\001\255\255\255\255\081\001\
\082\001\255\255\084\001\085\001\086\001\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\029\001\
\255\255\255\255\032\001\033\001\255\255\103\001\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\255\255\255\255\255\255\
\054\001\055\001\056\001\057\001\058\001\059\001\255\255\255\255\
\255\255\255\255\255\255\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\255\255\005\001\255\255\255\255\076\001\255\255\
\078\001\255\255\255\255\081\001\082\001\255\255\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\032\001\033\001\
\255\255\103\001\036\001\037\001\038\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\118\001\255\255\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\255\255\255\255\255\255\255\255\255\255\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\255\255\005\001\
\255\255\255\255\076\001\255\255\078\001\255\255\255\255\081\001\
\082\001\255\255\084\001\085\001\086\001\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\029\001\
\255\255\255\255\032\001\033\001\255\255\103\001\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\255\255\255\255\255\255\
\054\001\055\001\056\001\057\001\058\001\059\001\255\255\255\255\
\255\255\255\255\255\255\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\255\255\005\001\255\255\255\255\076\001\255\255\
\078\001\255\255\255\255\081\001\082\001\255\255\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\032\001\033\001\
\255\255\103\001\036\001\037\001\038\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\118\001\255\255\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\255\255\255\255\255\255\255\255\005\001\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\255\255\255\255\
\255\255\255\255\076\001\255\255\078\001\255\255\255\255\081\001\
\082\001\255\255\084\001\085\001\086\001\087\001\029\001\255\255\
\255\255\032\001\033\001\255\255\255\255\036\001\037\001\038\001\
\255\255\255\255\255\255\255\255\255\255\103\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\054\001\
\055\001\255\255\116\001\255\255\118\001\255\255\255\255\255\255\
\255\255\005\001\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\255\255\255\255\255\255\255\255\076\001\255\255\078\001\
\255\255\255\255\081\001\082\001\255\255\084\001\085\001\086\001\
\087\001\029\001\255\255\255\255\032\001\033\001\255\255\255\255\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\103\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\054\001\055\001\255\255\116\001\255\255\118\001\
\255\255\255\255\255\255\255\255\005\001\255\255\066\001\067\001\
\068\001\255\255\070\001\071\001\255\255\255\255\255\255\255\255\
\076\001\255\255\078\001\255\255\255\255\081\001\082\001\255\255\
\084\001\085\001\086\001\087\001\029\001\255\255\255\255\032\001\
\033\001\255\255\255\255\036\001\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\103\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\054\001\055\001\255\255\
\116\001\255\255\118\001\255\255\255\255\255\255\255\255\005\001\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\255\255\
\255\255\255\255\255\255\076\001\255\255\078\001\255\255\255\255\
\081\001\082\001\255\255\084\001\085\001\086\001\087\001\029\001\
\255\255\255\255\032\001\033\001\255\255\255\255\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\103\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\118\001\255\255\255\255\
\255\255\255\255\005\001\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\255\255\255\255\255\255\255\255\076\001\255\255\
\078\001\255\255\255\255\081\001\082\001\255\255\084\001\085\001\
\086\001\087\001\029\001\255\255\255\255\032\001\033\001\255\255\
\255\255\036\001\037\001\038\001\255\255\255\255\255\255\255\255\
\255\255\103\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\118\001\255\255\255\255\255\255\255\255\005\001\255\255\066\001\
\067\001\068\001\255\255\070\001\071\001\255\255\255\255\255\255\
\255\255\076\001\255\255\078\001\255\255\255\255\081\001\082\001\
\255\255\084\001\085\001\086\001\087\001\029\001\255\255\255\255\
\032\001\033\001\255\255\255\255\036\001\037\001\038\001\255\255\
\255\255\255\255\255\255\255\255\103\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\116\001\255\255\118\001\255\255\255\255\255\255\255\255\
\005\001\255\255\255\255\067\001\068\001\255\255\070\001\071\001\
\255\255\255\255\255\255\255\255\076\001\255\255\078\001\255\255\
\255\255\081\001\082\001\255\255\084\001\085\001\086\001\087\001\
\029\001\255\255\255\255\032\001\033\001\255\255\255\255\036\001\
\037\001\038\001\255\255\255\255\255\255\255\255\255\255\103\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\116\001\255\255\118\001\255\255\
\255\255\255\255\255\255\005\001\255\255\255\255\067\001\068\001\
\255\255\070\001\071\001\255\255\255\255\255\255\255\255\076\001\
\255\255\078\001\255\255\255\255\081\001\082\001\255\255\084\001\
\085\001\086\001\087\001\029\001\255\255\255\255\032\001\033\001\
\255\255\255\255\036\001\037\001\038\001\255\255\255\255\255\255\
\255\255\255\255\103\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\116\001\
\255\255\118\001\255\255\255\255\255\255\255\255\005\001\255\255\
\255\255\067\001\255\255\255\255\070\001\071\001\255\255\255\255\
\255\255\255\255\076\001\255\255\078\001\255\255\255\255\081\001\
\082\001\255\255\084\001\085\001\086\001\087\001\029\001\255\255\
\255\255\032\001\033\001\255\255\255\255\036\001\037\001\038\001\
\255\255\255\255\255\255\255\255\255\255\103\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\116\001\255\255\118\001\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\067\001\255\255\255\255\070\001\
\071\001\255\255\255\255\255\255\255\255\076\001\255\255\078\001\
\255\255\255\255\081\001\082\001\255\255\084\001\085\001\086\001\
\087\001\029\001\255\255\255\255\032\001\033\001\255\255\255\255\
\036\001\037\001\038\001\255\255\255\255\255\255\255\255\255\255\
\103\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\116\001\255\255\118\001\
\255\255\255\255\255\255\255\255\005\001\255\255\255\255\255\255\
\255\255\255\255\070\001\071\001\255\255\255\255\255\255\255\255\
\076\001\255\255\078\001\255\255\255\255\081\001\082\001\255\255\
\084\001\085\001\086\001\087\001\029\001\255\255\255\255\032\001\
\033\001\255\255\255\255\036\001\037\001\038\001\255\255\255\255\
\255\255\255\255\255\255\103\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\255\255\255\255\255\255\255\255\005\001\
\255\255\255\255\255\255\255\255\255\255\070\001\071\001\255\255\
\255\255\255\255\255\255\076\001\255\255\078\001\255\255\255\255\
\081\001\082\001\255\255\084\001\085\001\086\001\087\001\029\001\
\255\255\255\255\032\001\033\001\255\255\255\255\036\001\037\001\
\038\001\255\255\255\255\255\255\255\255\255\255\103\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\118\001\255\255\255\255\
\255\255\255\255\005\001\255\255\255\255\255\255\255\255\255\255\
\255\255\071\001\255\255\255\255\255\255\255\255\076\001\255\255\
\078\001\255\255\255\255\081\001\082\001\255\255\084\001\085\001\
\086\001\087\001\029\001\255\255\255\255\032\001\033\001\005\001\
\255\255\036\001\037\001\038\001\255\255\255\255\255\255\255\255\
\255\255\103\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\116\001\029\001\
\118\001\255\255\032\001\033\001\255\255\255\255\036\001\037\001\
\038\001\005\001\255\255\041\001\071\001\255\255\255\255\255\255\
\255\255\076\001\255\255\078\001\255\255\255\255\081\001\082\001\
\255\255\084\001\085\001\086\001\087\001\255\255\255\255\255\255\
\255\255\029\001\255\255\255\255\032\001\033\001\255\255\255\255\
\036\001\037\001\038\001\255\255\103\001\255\255\076\001\077\001\
\255\255\079\001\080\001\255\255\082\001\255\255\084\001\085\001\
\255\255\116\001\255\255\118\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\103\001\255\255\255\255\255\255\107\001\255\255\255\255\
\255\255\077\001\255\255\255\255\080\001\255\255\116\001\255\255\
\118\001\255\255\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\103\001\255\255\255\255\255\255\107\001\
\255\255\255\255\255\255\031\001\255\255\255\255\255\255\255\255\
\116\001\255\255\118\001\039\001\040\001\041\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\076\001\077\001\255\255\079\001\080\001\081\001\082\001\255\255\
\084\001\085\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\109\001\110\001\255\255\112\001\255\255\114\001\115\001\
\255\255\255\255\255\255\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\255\255\079\001\080\001\255\255\255\255\006\001\
\007\001\008\001\009\001\010\001\255\255\012\001\013\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\031\001\109\001\110\001\255\255\112\001\255\255\114\001\115\001\
\039\001\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\060\001\061\001\062\001\
\255\255\255\255\065\001\066\001\255\255\255\255\069\001\070\001\
\255\255\255\255\255\255\074\001\075\001\255\255\077\001\255\255\
\255\255\255\255\081\001\255\255\006\001\007\001\008\001\009\001\
\010\001\255\255\012\001\013\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\109\001\110\001\
\255\255\112\001\255\255\114\001\115\001\039\001\040\001\041\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\060\001\061\001\062\001\255\255\255\255\065\001\
\066\001\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\074\001\075\001\255\255\077\001\041\001\079\001\255\255\255\255\
\255\255\006\001\007\001\008\001\009\001\010\001\255\255\012\001\
\013\001\054\001\055\001\056\001\057\001\058\001\059\001\255\255\
\255\255\255\255\255\255\255\255\255\255\066\001\067\001\068\001\
\255\255\070\001\071\001\109\001\110\001\255\255\112\001\076\001\
\114\001\115\001\039\001\040\001\081\001\255\255\083\001\084\001\
\085\001\255\255\087\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\060\001\
\061\001\062\001\255\255\255\255\065\001\066\001\255\255\255\255\
\069\001\070\001\255\255\255\255\255\255\074\001\075\001\255\255\
\077\001\041\001\079\001\255\255\121\001\255\255\006\001\007\001\
\008\001\009\001\010\001\255\255\012\001\013\001\054\001\055\001\
\056\001\057\001\058\001\059\001\255\255\255\255\255\255\255\255\
\255\255\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\109\001\110\001\255\255\112\001\076\001\114\001\115\001\039\001\
\040\001\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\060\001\061\001\062\001\255\255\
\255\255\065\001\066\001\255\255\255\255\069\001\070\001\255\255\
\255\255\255\255\074\001\075\001\255\255\077\001\041\001\079\001\
\255\255\121\001\255\255\006\001\007\001\008\001\009\001\010\001\
\255\255\012\001\013\001\054\001\055\001\056\001\057\001\058\001\
\059\001\255\255\255\255\255\255\255\255\255\255\255\255\066\001\
\067\001\068\001\255\255\070\001\071\001\109\001\110\001\255\255\
\112\001\076\001\114\001\115\001\039\001\040\001\081\001\255\255\
\083\001\084\001\085\001\255\255\087\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\060\001\061\001\062\001\255\255\255\255\065\001\066\001\
\255\255\255\255\069\001\070\001\255\255\255\255\255\255\074\001\
\075\001\255\255\077\001\255\255\255\255\255\255\121\001\255\255\
\255\255\084\001\006\001\007\001\008\001\009\001\010\001\255\255\
\012\001\013\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\109\001\110\001\255\255\112\001\255\255\114\001\
\115\001\255\255\255\255\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\041\001\255\255\255\255\081\001\255\255\006\001\
\007\001\008\001\009\001\010\001\255\255\012\001\013\001\054\001\
\055\001\056\001\057\001\058\001\059\001\255\255\255\255\255\255\
\255\255\255\255\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\109\001\110\001\255\255\112\001\076\001\114\001\115\001\
\039\001\040\001\081\001\255\255\083\001\084\001\085\001\255\255\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\060\001\061\001\062\001\
\255\255\255\255\065\001\066\001\255\255\255\255\069\001\070\001\
\255\255\255\255\255\255\074\001\075\001\255\255\077\001\255\255\
\079\001\255\255\121\001\255\255\006\001\007\001\008\001\009\001\
\010\001\255\255\012\001\013\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\006\001\007\001\
\008\001\009\001\010\001\255\255\012\001\013\001\109\001\110\001\
\255\255\112\001\255\255\114\001\115\001\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\039\001\
\040\001\255\255\060\001\061\001\062\001\255\255\255\255\065\001\
\066\001\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\074\001\075\001\255\255\077\001\060\001\061\001\062\001\081\001\
\255\255\065\001\066\001\255\255\255\255\069\001\070\001\255\255\
\255\255\255\255\074\001\075\001\255\255\077\001\255\255\255\255\
\255\255\255\255\255\255\006\001\007\001\008\001\009\001\010\001\
\255\255\012\001\013\001\109\001\110\001\255\255\112\001\255\255\
\114\001\115\001\255\255\255\255\255\255\006\001\007\001\008\001\
\009\001\010\001\255\255\012\001\013\001\109\001\110\001\255\255\
\112\001\255\255\114\001\115\001\039\001\040\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\039\001\040\001\
\255\255\060\001\061\001\062\001\255\255\255\255\065\001\066\001\
\255\255\255\255\069\001\070\001\255\255\255\255\255\255\074\001\
\075\001\255\255\077\001\060\001\061\001\062\001\255\255\255\255\
\065\001\066\001\255\255\255\255\069\001\070\001\255\255\255\255\
\255\255\074\001\075\001\255\255\077\001\255\255\255\255\255\255\
\255\255\255\255\006\001\007\001\008\001\009\001\010\001\255\255\
\012\001\013\001\109\001\110\001\255\255\112\001\255\255\114\001\
\115\001\255\255\255\255\255\255\006\001\007\001\008\001\009\001\
\010\001\255\255\012\001\013\001\109\001\110\001\255\255\112\001\
\255\255\114\001\115\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\039\001\040\001\255\255\
\060\001\061\001\062\001\255\255\255\255\065\001\066\001\255\255\
\255\255\069\001\070\001\255\255\255\255\255\255\074\001\075\001\
\255\255\077\001\060\001\061\001\062\001\255\255\255\255\065\001\
\066\001\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\074\001\075\001\255\255\077\001\255\255\255\255\255\255\255\255\
\255\255\006\001\007\001\008\001\009\001\010\001\255\255\012\001\
\013\001\109\001\110\001\255\255\112\001\255\255\114\001\115\001\
\255\255\255\255\255\255\006\001\007\001\008\001\009\001\010\001\
\255\255\012\001\013\001\109\001\110\001\255\255\112\001\255\255\
\114\001\115\001\039\001\040\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\039\001\040\001\255\255\060\001\
\061\001\062\001\255\255\255\255\065\001\066\001\255\255\255\255\
\069\001\070\001\255\255\255\255\255\255\074\001\075\001\255\255\
\077\001\060\001\061\001\062\001\255\255\255\255\065\001\066\001\
\255\255\255\255\069\001\070\001\255\255\255\255\255\255\074\001\
\075\001\255\255\077\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\109\001\110\001\255\255\112\001\006\001\114\001\115\001\009\001\
\010\001\011\001\012\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\109\001\110\001\255\255\112\001\255\255\114\001\
\115\001\255\255\255\255\029\001\006\001\255\255\032\001\009\001\
\010\001\011\001\012\001\255\255\255\255\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\029\001\255\255\255\255\032\001\255\255\
\255\255\255\255\060\001\061\001\062\001\039\001\040\001\065\001\
\066\001\255\255\255\255\069\001\255\255\255\255\255\255\255\255\
\255\255\255\255\076\001\077\001\255\255\255\255\255\255\255\255\
\255\255\255\255\060\001\061\001\062\001\255\255\255\255\065\001\
\066\001\255\255\255\255\069\001\094\001\255\255\255\255\255\255\
\255\255\255\255\255\255\077\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\109\001\110\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\094\001\255\255\255\255\255\255\
\255\255\255\255\041\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\109\001\110\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\064\001\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\072\001\073\001\255\255\255\255\076\001\255\255\255\255\
\255\255\080\001\081\001\255\255\083\001\084\001\085\001\255\255\
\087\001\041\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\064\001\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\072\001\073\001\121\001\255\255\076\001\255\255\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\041\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\064\001\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\121\001\255\255\076\001\255\255\255\255\255\255\080\001\
\081\001\041\001\083\001\084\001\085\001\255\255\087\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\064\001\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\072\001\073\001\255\255\255\255\076\001\255\255\255\255\255\255\
\121\001\081\001\041\001\083\001\084\001\085\001\255\255\087\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\064\001\255\255\066\001\067\001\068\001\255\255\070\001\
\071\001\072\001\073\001\255\255\255\255\076\001\255\255\255\255\
\255\255\121\001\081\001\041\001\083\001\084\001\085\001\255\255\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\064\001\255\255\066\001\067\001\068\001\255\255\
\070\001\071\001\072\001\073\001\255\255\255\255\076\001\255\255\
\255\255\255\255\121\001\081\001\041\001\083\001\084\001\085\001\
\255\255\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\054\001\055\001\056\001\057\001\058\001\059\001\060\001\
\061\001\255\255\255\255\255\255\255\255\066\001\067\001\068\001\
\255\255\070\001\071\001\072\001\073\001\255\255\255\255\076\001\
\255\255\255\255\255\255\121\001\081\001\041\001\083\001\084\001\
\085\001\255\255\087\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\255\255\255\255\255\255\255\255\066\001\067\001\
\068\001\255\255\070\001\071\001\072\001\073\001\255\255\255\255\
\076\001\255\255\255\255\255\255\121\001\081\001\041\001\083\001\
\084\001\085\001\255\255\087\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\255\255\255\255\255\255\255\255\066\001\
\067\001\068\001\255\255\070\001\071\001\072\001\073\001\255\255\
\255\255\076\001\255\255\255\255\255\255\121\001\081\001\041\001\
\083\001\084\001\085\001\255\255\087\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\054\001\055\001\056\001\057\001\
\058\001\059\001\255\255\255\255\255\255\255\255\255\255\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\072\001\073\001\
\255\255\255\255\076\001\255\255\255\255\255\255\121\001\081\001\
\041\001\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\054\001\055\001\056\001\
\057\001\058\001\059\001\255\255\255\255\255\255\255\255\255\255\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\255\255\255\255\076\001\255\255\255\255\255\255\121\001\
\081\001\041\001\083\001\084\001\085\001\255\255\087\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\054\001\055\001\
\056\001\057\001\058\001\059\001\255\255\255\255\255\255\255\255\
\041\001\255\255\066\001\067\001\068\001\255\255\070\001\071\001\
\255\255\255\255\255\255\255\255\076\001\054\001\055\001\255\255\
\121\001\081\001\255\255\083\001\084\001\085\001\255\255\087\001\
\041\001\066\001\067\001\068\001\255\255\070\001\071\001\255\255\
\255\255\255\255\255\255\076\001\255\255\054\001\055\001\255\255\
\081\001\255\255\083\001\084\001\085\001\255\255\087\001\041\001\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\255\255\
\255\255\121\001\255\255\076\001\054\001\055\001\255\255\255\255\
\081\001\255\255\083\001\084\001\085\001\255\255\087\001\041\001\
\066\001\067\001\068\001\255\255\070\001\071\001\255\255\255\255\
\121\001\255\255\076\001\255\255\255\255\255\255\255\255\081\001\
\255\255\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\066\001\067\001\068\001\255\255\070\001\071\001\255\255\255\255\
\121\001\255\255\076\001\255\255\255\255\255\255\255\255\081\001\
\255\255\083\001\084\001\085\001\255\255\087\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\121\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\121\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\064\001\
\255\255\066\001\067\001\068\001\255\255\070\001\071\001\072\001\
\073\001\074\001\075\001\255\255\077\001\078\001\255\255\080\001\
\255\255\082\001\255\255\084\001\085\001\255\255\087\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COLON2\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  LGHOST\000\
  RGHOST\000\
  "

let yynames_block = "\
  SPEC\000\
  DECL\000\
  CODE_ANNOT\000\
  LOOP_ANNOT\000\
  ATTRIBUTE_ANNOT\000\
  IDENT\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  BOOL\000\
  CHAR\000\
  INT\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  THREAD\000\
  THREAD_LOCAL\000\
  GHOST\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  NORETURN\000\
  STATIC_ASSERT\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA_LINE\000\
  PRAGMA\000\
  LGHOST_ELSE\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 446 "src/kernel_internals/parsing/cparser.mly"
                ( _1 )
# 3315 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    Obj.repr(
# 448 "src/kernel_internals/parsing/cparser.mly"
                    (_1)
# 3322 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 451 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 3328 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 452 "src/kernel_internals/parsing/cparser.mly"
                                        ( (false,_1) :: _2 )
# 3336 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'ghost_glob_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'ghost_globals) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 453 "src/kernel_internals/parsing/cparser.mly"
                                                  ( _2 @ _3 )
# 3345 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 454 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2 )
# 3353 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 458 "src/kernel_internals/parsing/cparser.mly"
         ( ghost_global:=true )
# 3359 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_glob_begin))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 463 "src/kernel_internals/parsing/cparser.mly"
                                        ( (true,_1)::_2 )
# 3367 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 464 "src/kernel_internals/parsing/cparser.mly"
                                        ( (true,_1)::_2 )
# 3375 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    Obj.repr(
# 465 "src/kernel_internals/parsing/cparser.mly"
                                        ( ghost_global:=false; [] )
# 3381 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.decl list) in
    Obj.repr(
# 470 "src/kernel_internals/parsing/cparser.mly"
                   ( GLOBANNOT _1 )
# 3388 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 471 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3395 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 472 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3402 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 477 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2), [ _3 ]) )
# 3411 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 479 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2),
                 List.map
                   (fun (x,y) ->
                      if x then
                        Errorloc.parse_error "invalid ghost in extern linkage \
                                              specification"
		      else y)
                   _4)  )
# 3429 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 488 "src/kernel_internals/parsing/cparser.mly"
                                        ( GLOBASM (fst _3, (*handleLoc*) _1) )
# 3439 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'pragma) in
    Obj.repr(
# 489 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 3446 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'old_pardef_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 494 "src/kernel_internals/parsing/cparser.mly"
    (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      (* Make the function declarator *)
      doDeclaration None loc []
        [((_1, PROTO(JUSTBASE, pardecl,[],isva),
           ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
    )
# 3465 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 503 "src/kernel_internals/parsing/cparser.mly"
                                (
  let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
  doDeclaration None loc []
    [((_1, PROTO(JUSTBASE,[],[],false),
       ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
)
# 3479 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 512 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 3486 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 513 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3493 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 517 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 3500 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    Obj.repr(
# 521 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3506 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    Obj.repr(
# 522 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3512 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 528 "src/kernel_internals/parsing/cparser.mly"
         ( make_expr (VARIABLE _1) )
# 3519 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 529 "src/kernel_internals/parsing/cparser.mly"
                   (
  let (v,expr_loc) = _1 in { expr_loc; expr_node = CONSTANT v } )
# 3527 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 532 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (PAREN (smooth_expression _1)) )
# 3534 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 533 "src/kernel_internals/parsing/cparser.mly"
                       ( make_expr (GNU_BODY (fst3 _2)) )
# 3542 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 537 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 3549 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 539 "src/kernel_internals/parsing/cparser.mly"
      (make_expr (INDEX (_1, smooth_expression _2)))
# 3557 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_arguments_opt) in
    Obj.repr(
# 540 "src/kernel_internals/parsing/cparser.mly"
                                                                 (make_expr (CALL (_1, _3, _5)))
# 3567 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 542 "src/kernel_internals/parsing/cparser.mly"
      ( let b, d = _5 in
        let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5) in
        let loc_f = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        make_expr
          (CALL
             ({ expr_loc = loc_f;
                expr_node = VARIABLE "__builtin_va_arg"},
              [_3; { expr_loc = loc;
                     expr_node = TYPE_SIZEOF (b, d)}],[]))
      )
# 3586 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 553 "src/kernel_internals/parsing/cparser.mly"
      ( let b1,d1 = _3 in
        let b2,d2 = _5 in
        let loc_f = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        let loc1 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3) in
        let loc2 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5) in
        make_expr
          (CALL
             ({expr_loc = loc_f;
               expr_node = VARIABLE "__builtin_types_compatible_p"},
              [ { expr_loc = loc1; expr_node = TYPE_SIZEOF(b1,d1)};
                { expr_loc = loc2; expr_node = TYPE_SIZEOF(b2,d2)}],[]))
      )
# 3607 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 566 "src/kernel_internals/parsing/cparser.mly"
    (
      let loc_f = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      let arg = transformOffsetOf _3 _5 in
      let builtin = { expr_loc = loc_f;
                      expr_node = VARIABLE "__builtin_offsetof" }
      in
      make_expr (CALL (builtin, [ arg ], []))
    )
# 3624 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 574 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)))
# 3632 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 575 "src/kernel_internals/parsing/cparser.mly"
                                          ( make_expr (MEMBEROFPTR (_1, _3)) )
# 3640 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 576 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (UNARY (POSINCR, _1)) )
# 3648 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 577 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (POSDECR, _1)) )
# 3656 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 580 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, COMPOUND_INIT _5)) )
# 3667 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 584 "src/kernel_internals/parsing/cparser.mly"
                  ( make_expr (VARIABLE _1) )
# 3674 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'offsetof_member_designator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 586 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (MEMBEROF (_1, _3)) )
# 3682 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 588 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (INDEX (_1, smooth_expression _2)) )
# 3690 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 593 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3697 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 595 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREINCR, _2)))
# 3705 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 597 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREDECR, _2)))
# 3713 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 599 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (EXPR_SIZEOF _2))
# 3721 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 601 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_SIZEOF (b, d)) )
# 3730 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 603 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (EXPR_ALIGNOF _2) )
# 3738 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 605 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_ALIGNOF (b, d)) )
# 3747 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 607 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (PLUS, _2)) )
# 3755 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 609 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (MINUS, _2)) )
# 3763 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 611 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (MEMOF, _2)) )
# 3771 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 613 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (ADDROF, _2)))
# 3779 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 615 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (NOT, _2)) )
# 3787 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 617 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (BNOT, _2)) )
# 3795 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 619 "src/kernel_internals/parsing/cparser.mly"
                                             ( make_expr (LABELADDR _2) )
# 3803 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 623 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3810 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 625 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, SINGLE_INIT _4)) )
# 3819 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 629 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3826 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 631 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MUL, _1, _3)) )
# 3835 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 633 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(DIV, _1, _3)) )
# 3843 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 635 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MOD, _1, _3)) )
# 3851 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 639 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 3858 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 641 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD, _1, _3)) )
# 3867 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 643 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB, _1, _3)) )
# 3876 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 647 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3883 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 649 "src/kernel_internals/parsing/cparser.mly"
   (make_expr (BINARY(SHL, _1, _3)) )
# 3891 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 651 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR, _1, _3)) )
# 3899 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 656 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 3906 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 658 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LT, _1, _3)) )
# 3914 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 660 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GT, _1, _3)) )
# 3922 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 662 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LE, _1, _3)) )
# 3930 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 664 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GE, _1, _3)) )
# 3938 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 668 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3945 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 670 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(EQ, _1, _3)) )
# 3953 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 672 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(NE, _1, _3)) )
# 3961 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 676 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3968 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 678 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND, _1, _3)) )
# 3977 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 682 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3984 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 684 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR, _1, _3)) )
# 3992 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 688 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3999 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 690 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR, _1, _3)) )
# 4007 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 694 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 4014 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 696 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(AND, _1, _3)) )
# 4023 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 700 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 4030 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 702 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(OR, _1, _3)) )
# 4038 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 706 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 4045 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 708 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (QUESTION (_1, _3, _5)) )
# 4054 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 715 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 4061 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 717 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ASSIGN, _1, _3)) )
# 4069 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 719 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD_ASSIGN, _1, _3)) )
# 4077 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 721 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB_ASSIGN, _1, _3)) )
# 4085 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 723 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MUL_ASSIGN, _1, _3)) )
# 4093 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 725 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(DIV_ASSIGN, _1, _3)) )
# 4101 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 727 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MOD_ASSIGN, _1, _3)) )
# 4109 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 729 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND_ASSIGN, _1, _3)) )
# 4117 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 731 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR_ASSIGN, _1, _3)) )
# 4125 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 733 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR_ASSIGN, _1, _3)) )
# 4133 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 735 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHL_ASSIGN, _1, _3)) )
# 4141 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 737 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR_ASSIGN, _1, _3)))
# 4149 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 741 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 4156 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 746 "src/kernel_internals/parsing/cparser.mly"
              (CONST_INT (fst _1), snd _1)
# 4163 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 747 "src/kernel_internals/parsing/cparser.mly"
                (CONST_FLOAT (fst _1), snd _1)
# 4170 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 748 "src/kernel_internals/parsing/cparser.mly"
               (CONST_CHAR (fst _1), snd _1)
# 4177 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 749 "src/kernel_internals/parsing/cparser.mly"
                (CONST_WCHAR (fst _1), snd _1)
# 4184 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 750 "src/kernel_internals/parsing/cparser.mly"
                     (CONST_STRING (fst _1), snd _1)
# 4191 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'wstring_list) in
    Obj.repr(
# 751 "src/kernel_internals/parsing/cparser.mly"
                  (CONST_WSTRING (List.concat (fst _1)), snd _1)
# 4198 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'string_list) in
    Obj.repr(
# 757 "src/kernel_internals/parsing/cparser.mly"
                                        ( intlist_to_string (fst _1), snd _1 )
# 4205 "src/kernel_internals/parsing/cparser.ml"
               : string * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 761 "src/kernel_internals/parsing/cparser.mly"
                                        ( [fst _1], snd _1 )
# 4212 "src/kernel_internals/parsing/cparser.ml"
               : 'string_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'string_list) in
    Obj.repr(
# 762 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4220 "src/kernel_internals/parsing/cparser.ml"
               : 'string_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 766 "src/kernel_internals/parsing/cparser.mly"
                                        ( [fst _1], snd _1 )
# 4227 "src/kernel_internals/parsing/cparser.ml"
               : 'wstring_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'wstring_list) in
    Obj.repr(
# 767 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4235 "src/kernel_internals/parsing/cparser.ml"
               : 'wstring_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'wstring_list) in
    Obj.repr(
# 768 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4243 "src/kernel_internals/parsing/cparser.ml"
               : 'wstring_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'string_list) in
    Obj.repr(
# 769 "src/kernel_internals/parsing/cparser.mly"
                                        ( merge_string _1 _2 )
# 4251 "src/kernel_internals/parsing/cparser.ml"
               : 'wstring_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 773 "src/kernel_internals/parsing/cparser.mly"
                  (_1)
# 4258 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 774 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 4266 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 776 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 4274 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 781 "src/kernel_internals/parsing/cparser.mly"
                        ( SINGLE_INIT _1 )
# 4281 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 783 "src/kernel_internals/parsing/cparser.mly"
   ( COMPOUND_INIT _2)
# 4290 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 786 "src/kernel_internals/parsing/cparser.mly"
                                                   ( [_1] )
# 4297 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 787 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _1 :: _3 )
# 4305 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 790 "src/kernel_internals/parsing/cparser.mly"
                                            ( [] )
# 4311 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 791 "src/kernel_internals/parsing/cparser.mly"
                                            ( _1 )
# 4318 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'eq_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 794 "src/kernel_internals/parsing/cparser.mly"
                                            ( (_1, _3) )
# 4327 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gcc_init_designators) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 795 "src/kernel_internals/parsing/cparser.mly"
                                         ( (_1, _2) )
# 4335 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 796 "src/kernel_internals/parsing/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 4342 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 799 "src/kernel_internals/parsing/cparser.mly"
                             ( () )
# 4348 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 801 "src/kernel_internals/parsing/cparser.mly"
                                 ( () )
# 4354 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 804 "src/kernel_internals/parsing/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 4362 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 805 "src/kernel_internals/parsing/cparser.mly"
                                                       ( ATINDEX_INIT(_2, _4) )
# 4370 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 807 "src/kernel_internals/parsing/cparser.mly"
        ( ATINDEXRANGE_INIT(_2, _4) )
# 4378 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    Obj.repr(
# 810 "src/kernel_internals/parsing/cparser.mly"
                                        ( NEXT_INIT )
# 4384 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 811 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 4391 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 815 "src/kernel_internals/parsing/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 4398 "src/kernel_internals/parsing/cparser.ml"
               : 'gcc_init_designators))
; (fun __caml_parser_env ->
    Obj.repr(
# 819 "src/kernel_internals/parsing/cparser.mly"
                                    ( [] )
# 4404 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_arguments_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_arguments) in
    Obj.repr(
# 820 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 4411 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_arguments_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression list) in
    Obj.repr(
# 823 "src/kernel_internals/parsing/cparser.mly"
                                                      ( _3 )
# 4419 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_arguments))
; (fun __caml_parser_env ->
    Obj.repr(
# 826 "src/kernel_internals/parsing/cparser.mly"
                                    ( [] )
# 4425 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 827 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 4432 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 831 "src/kernel_internals/parsing/cparser.mly"
                     (make_expr NOTHING)
# 4438 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 832 "src/kernel_internals/parsing/cparser.mly"
                           (smooth_expression _1 )
# 4445 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 836 "src/kernel_internals/parsing/cparser.mly"
                                           ( [_1] )
# 4452 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 837 "src/kernel_internals/parsing/cparser.mly"
                                                  ( _1 :: _3 )
# 4460 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 841 "src/kernel_internals/parsing/cparser.mly"
                                    ( make_expr NOTHING )
# 4466 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 842 "src/kernel_internals/parsing/cparser.mly"
                                    ( smooth_expression _1 )
# 4473 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 846 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _2 )
# 4481 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 850 "src/kernel_internals/parsing/cparser.mly"
                                                       ( _2 )
# 4488 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'block_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'block_attrs) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 857 "src/kernel_internals/parsing/cparser.mly"
      (!Lexerhack.pop_context();
       { blabels = _2;
         battrs = _3;
         bstmts = _4 },
       _1, _5
      )
# 4504 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 865 "src/kernel_internals/parsing/cparser.mly"
            ( !Lexerhack.push_context (); _1 )
# 4511 "src/kernel_internals/parsing/cparser.ml"
               : 'block_begin))
; (fun __caml_parser_env ->
    Obj.repr(
# 869 "src/kernel_internals/parsing/cparser.mly"
                                                            ( [] )
# 4517 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 871 "src/kernel_internals/parsing/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 4524 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 876 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 )
# 4531 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 878 "src/kernel_internals/parsing/cparser.mly"
        ( _1 @ no_ghost_stmt (DEFINITION(_2)) :: _3 )
# 4540 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'statement) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 880 "src/kernel_internals/parsing/cparser.mly"
            ( _1 @ _2 @ _3 )
# 4549 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 881 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 @ _3 )
# 4558 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    Obj.repr(
# 885 "src/kernel_internals/parsing/cparser.mly"
                    ( [] )
# 4564 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list) in
    Obj.repr(
# 886 "src/kernel_internals/parsing/cparser.mly"
                    ( _1 )
# 4571 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Logic_ptree.code_annot * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 890 "src/kernel_internals/parsing/cparser.mly"
                             ( no_ghost [Cabs.CODE_ANNOT _1] @ _2)
# 4579 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.statement list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 892 "src/kernel_internals/parsing/cparser.mly"
       ( (in_ghost _2) @ _4 )
# 4587 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 896 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [] )
# 4593 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 897 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _2 @ _4 )
# 4602 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 900 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [ _1 ] )
# 4609 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 901 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _1 :: _3 )
# 4617 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 906 "src/kernel_internals/parsing/cparser.mly"
              ( _1 )
# 4624 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'annot_list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 907 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 @ _2 )
# 4632 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    Obj.repr(
# 911 "src/kernel_internals/parsing/cparser.mly"
            (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost_stmt (NOP loc)
    )
# 4641 "src/kernel_internals/parsing/cparser.ml"
               : 'else_part))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 917 "src/kernel_internals/parsing/cparser.mly"
    ( in_block _2 )
# 4648 "src/kernel_internals/parsing/cparser.ml"
               : 'else_part))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'annotated_statement) in
    Obj.repr(
# 919 "src/kernel_internals/parsing/cparser.mly"
    ( in_ghost_block ~battrs:[ (Cil.frama_c_ghost_else , []) ] _2 )
# 4656 "src/kernel_internals/parsing/cparser.ml"
               : 'else_part))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'annotated_statement) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 922 "src/kernel_internals/parsing/cparser.mly"
    (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      Kernel.warning ~wkey:Kernel.wkey_ghost_bad_use ~source:(fst loc)
        "Invalid ghost else ignored@." ;
      in_block _5
    )
# 4670 "src/kernel_internals/parsing/cparser.ml"
               : 'else_part))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 930 "src/kernel_internals/parsing/cparser.mly"
               ( no_ghost [NOP _1] )
# 4677 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 932 "src/kernel_internals/parsing/cparser.mly"
      (
        let bs = _2 in
        match Logic_lexer.spec _1 with
        | Some (loc',spec) ->
          let spec = no_ghost [Cabs.CODE_SPEC (spec, (fst _1, loc'))] in
          spec @ _2
        | None -> bs
      )
# 4692 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 941 "src/kernel_internals/parsing/cparser.mly"
   ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
            no_ghost [COMPUTATION (smooth_expression _1,loc)])
# 4701 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 943 "src/kernel_internals/parsing/cparser.mly"
          ( let (x,y,z) = _1 in no_ghost [BLOCK (x, y, z)])
# 4708 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'annotated_statement) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'else_part) in
    Obj.repr(
# 945 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
          no_ghost [IF (smooth_expression _2,
                       in_block _3, _4, loc)])
# 4720 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 949 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
          no_ghost [SWITCH (smooth_expression _2, in_block _3, loc)])
# 4730 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 953 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [WHILE (_1, smooth_expression _3, in_block _4, loc)] )
# 4741 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'annotated_statement) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 957 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [DOWHILE (_1, smooth_expression _5, in_block _3, loc)])
# 4754 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'for_clause) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 962 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.symbol_end_pos ()) in
      no_ghost [FOR (_1, _4, _5, _7, in_block _9, loc)])
# 4769 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 965 "src/kernel_internals/parsing/cparser.mly"
 ((* The only attribute that should appear here
            is "unused". For now, we drop this on the
            floor, since unused labels are usually
            removed anyways by Rmtmps. *)
          let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 2) in
          match _4 with
          | [] -> (* should not happen if grammar is written correctly *)
            parse_error "empty statement after label"
          | s :: others -> no_ghost [LABEL(_1,s,loc)] @ others )
# 4786 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 976 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.rhs_end_pos 3) in
              no_ghost [CASE (_2, in_block _4, loc)])
# 4796 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 979 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.rhs_end_pos 5) in
              no_ghost [CASERANGE (_2, _4, in_block _6, loc)])
# 4807 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 982 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos(), Parsing.symbol_end_pos ()) in
              no_ghost [DEFAULT (in_block _3, loc)])
# 4816 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 984 "src/kernel_internals/parsing/cparser.mly"
                     (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [RETURN ({ expr_loc = loc; expr_node = NOTHING}, loc)]
    )
# 4827 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 988 "src/kernel_internals/parsing/cparser.mly"
                                      (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [RETURN (smooth_expression _2, loc)]
    )
# 4839 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 992 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [BREAK loc]
    )
# 4850 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 996 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [CONTINUE loc]
    )
# 4861 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1000 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [GOTO (_2, loc)]
    )
# 4873 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1004 "src/kernel_internals/parsing/cparser.mly"
                                         (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [COMPGOTO (smooth_expression _3, loc) ]
    )
# 4886 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1008 "src/kernel_internals/parsing/cparser.mly"
                                                                    (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [ASM (_3, mk_asm_templates _5, _6, loc)]
    )
# 4902 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1012 "src/kernel_internals/parsing/cparser.mly"
                                                               (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      no_ghost [ASM (_2, mk_asm_templates _4, _5, loc)]
    )
# 4917 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1016 "src/kernel_internals/parsing/cparser.mly"
            ( no_ghost [ASM ([], [fst _1], None, snd _1)])
# 4924 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1017 "src/kernel_internals/parsing/cparser.mly"
                                                  (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      let loc_e = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 4, Parsing.rhs_end_pos 4) in
      let b, _, _ = _2 in
      let h, _, _ = _5 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/except in GCC code";
      no_ghost
        [TRY_EXCEPT (b, {expr_loc = loc_e; expr_node = COMMA _4}, h, loc)]
    )
# 4944 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1027 "src/kernel_internals/parsing/cparser.mly"
                            (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos ()) in
      let b, _, _ = _2 in
      let h, _, _ = _4 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/finally in GCC code";
      no_ghost [TRY_FINALLY (b, h, loc)]
    )
# 4961 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    Obj.repr(
# 1038 "src/kernel_internals/parsing/cparser.mly"
                ( [] )
# 4967 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotations) in
    Obj.repr(
# 1039 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 4974 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotation) in
    Obj.repr(
# 1043 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 4981 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.code_annot list * Cabs.cabsloc) in
    Obj.repr(
# 1055 "src/kernel_internals/parsing/cparser.mly"
               ( fst _1 )
# 4988 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1059 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_EXP _1 )
# 4996 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 1060 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_DECL _1 )
# 5003 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    Obj.repr(
# 1064 "src/kernel_internals/parsing/cparser.mly"
                        ([])
# 5009 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_parameter_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_parameter) in
    Obj.repr(
# 1065 "src/kernel_internals/parsing/cparser.mly"
                        (_1)
# 5016 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_parameter_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'rest_par_list) in
    Obj.repr(
# 1069 "src/kernel_internals/parsing/cparser.mly"
                                                               ( let (l, _) = _3 in l )
# 5024 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_parameter))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1074 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) _2 )
# 5033 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1076 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) [] )
# 5041 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1078 "src/kernel_internals/parsing/cparser.mly"
          ( doDeclaration (Some _1) ((snd _2)) (fst _2) _3 )
# 5051 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1080 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration (Some _1) ((snd _2)) (fst _2) [] )
# 5060 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'static_assert_declaration) in
    Obj.repr(
# 1082 "src/kernel_internals/parsing/cparser.mly"
      ( let (e, m, loc) = _1 in STATIC_ASSERT (e, m, loc) )
# 5067 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1088 "src/kernel_internals/parsing/cparser.mly"
      (
        (_3, "", _1)
      )
# 5078 "src/kernel_internals/parsing/cparser.ml"
               : 'static_assert_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    Obj.repr(
# 1092 "src/kernel_internals/parsing/cparser.mly"
      (
        (_3, fst _5, _1)
      )
# 5090 "src/kernel_internals/parsing/cparser.ml"
               : 'static_assert_declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 1098 "src/kernel_internals/parsing/cparser.mly"
                                                 ( [_1] )
# 5097 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.init_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr_list) in
    Obj.repr(
# 1099 "src/kernel_internals/parsing/cparser.mly"
                                                      ( _1 :: _3 )
# 5105 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr) in
    Obj.repr(
# 1104 "src/kernel_internals/parsing/cparser.mly"
                       ( [ _1 ] )
# 5112 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'init_declarator_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'init_declarator_attr_list) in
    Obj.repr(
# 1105 "src/kernel_internals/parsing/cparser.mly"
                                                       ( _1 :: _3 )
# 5120 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 1109 "src/kernel_internals/parsing/cparser.mly"
                                      (
    let ((name, decl, attrs, loc), init) = _2 in
    ((name, PARENTYPE (_1,decl,[]), attrs, loc), init)
  )
# 5131 "src/kernel_internals/parsing/cparser.ml"
               : 'init_declarator_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1116 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, NO_INIT) )
# 5138 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 1118 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, _3) )
# 5146 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1123 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecTypedef, _1  )
# 5153 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1124 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage EXTERN, _1 )
# 5160 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1125 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage STATIC, _1 )
# 5167 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1126 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage AUTO, _1 )
# 5174 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1127 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage REGISTER, _1)
# 5181 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1129 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecInline, _1 )
# 5188 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1130 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecAttr
                         (("noreturn",[make_expr (VARIABLE "c11")])), _1 )
# 5196 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.spec_elem * cabsloc) in
    Obj.repr(
# 1132 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 5203 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1133 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecAttr (fst _1), snd _1 )
# 5210 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 1137 "src/kernel_internals/parsing/cparser.mly"
                                       ( fst _1 :: _2, snd _1 )
# 5218 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1138 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 5226 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1141 "src/kernel_internals/parsing/cparser.mly"
                                                ( fst _1 :: _2, snd _1 )
# 5234 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1142 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 5242 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    Obj.repr(
# 1147 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5248 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1148 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 )
# 5255 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 1155 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5261 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_no_named) in
    Obj.repr(
# 1156 "src/kernel_internals/parsing/cparser.mly"
                                                 ( fst _1 )
# 5268 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1159 "src/kernel_internals/parsing/cparser.mly"
                    ( Tvoid, _1)
# 5275 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1160 "src/kernel_internals/parsing/cparser.mly"
                    ( Tchar, _1 )
# 5282 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1161 "src/kernel_internals/parsing/cparser.mly"
                    ( Tbool, _1 )
# 5289 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1162 "src/kernel_internals/parsing/cparser.mly"
                    ( Tshort, _1 )
# 5296 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1163 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint, _1 )
# 5303 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1164 "src/kernel_internals/parsing/cparser.mly"
                    ( Tlong, _1 )
# 5310 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1165 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint64, _1 )
# 5317 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1166 "src/kernel_internals/parsing/cparser.mly"
                    ( Tfloat, _1 )
# 5324 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1167 "src/kernel_internals/parsing/cparser.mly"
                    ( Tdouble, _1 )
# 5331 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1168 "src/kernel_internals/parsing/cparser.mly"
                    ( Tsigned, _1 )
# 5338 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1169 "src/kernel_internals/parsing/cparser.mly"
                    ( Tunsigned, _1 )
# 5345 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1171 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 5353 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1173 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, None,    _2), _1 )
# 5362 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1175 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 5373 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1177 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 5383 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1179 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 5395 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1181 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 5406 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1183 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 5414 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1185 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 5425 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1187 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 5435 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1189 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 5447 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1191 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 5458 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1193 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 5466 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1195 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 5478 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1197 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 5489 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1199 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 5502 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1201 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 5514 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1202 "src/kernel_internals/parsing/cparser.mly"
                    (
      (Tnamed _1, Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos()))
      )
# 5523 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1205 "src/kernel_internals/parsing/cparser.mly"
                                        ( TtypeofE _3, _1 )
# 5532 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1206 "src/kernel_internals/parsing/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 5542 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1212 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 5548 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1214 "src/kernel_internals/parsing/cparser.mly"
                                         ( FIELD (fst _1,
                                            [(missingFieldDecl, None)]) :: _3 )
# 5558 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1218 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 5566 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1220 "src/kernel_internals/parsing/cparser.mly"
                                          ( FIELD (fst _1, _2)
                                            :: _4 )
# 5577 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1223 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5585 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'static_assert_declaration) in
    Obj.repr(
# 1226 "src/kernel_internals/parsing/cparser.mly"
                                         (
       let (e, m, loc) = _1 in
       [ STATIC_ASSERT_FG (e, m, loc) ]
   )
# 5595 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'static_assert_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1231 "src/kernel_internals/parsing/cparser.mly"
                                                              (
       let (e, m, loc) = _1 in
       STATIC_ASSERT_FG (e, m, loc) :: _3
   )
# 5607 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1238 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 5614 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name * expression option) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1239 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 5622 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1242 "src/kernel_internals/parsing/cparser.mly"
                                    ( (_1, None) )
# 5629 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1244 "src/kernel_internals/parsing/cparser.mly"
                                    ( let (n,decl,al,loc) = _1 in
                                      let al' = al @ _4 in
                                     ((n,decl,al',loc), Some _3) )
# 5640 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1247 "src/kernel_internals/parsing/cparser.mly"
                                    ( (missingFieldDecl, Some _2) )
# 5647 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1251 "src/kernel_internals/parsing/cparser.mly"
                  ([_1])
# 5654 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1252 "src/kernel_internals/parsing/cparser.mly"
                                       (_1 @ [_3])
# 5662 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1255 "src/kernel_internals/parsing/cparser.mly"
            (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (), Parsing.symbol_end_pos()) in
      (_1, { expr_node = NOTHING; expr_loc = loc }, loc)
    )
# 5672 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1259 "src/kernel_internals/parsing/cparser.mly"
                         (
      (_1, _3, Cil_datatype.Location.of_lexing_loc (Parsing.symbol_start_pos (),Parsing.symbol_end_pos()))
    )
# 5682 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1266 "src/kernel_internals/parsing/cparser.mly"
                                               (
     let (n, decl) = _2 in (n, applyPointer (fst _1) decl, _3, (snd _1))
   )
# 5693 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'comma_expression_opt) in
    Obj.repr(
# 1273 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1,_2 )
# 5701 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1274 "src/kernel_internals/parsing/cparser.mly"
                                               (
    fst _1::_2  @ ["static",[]], smooth_expression _4
  )
# 5713 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1277 "src/kernel_internals/parsing/cparser.mly"
                                     (
    ("static",[]) :: _2, smooth_expression _3
  )
# 5724 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1285 "src/kernel_internals/parsing/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 5731 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.name) in
    Obj.repr(
# 1288 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n,decl,al,_) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 5741 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attributes_or_static) in
    Obj.repr(
# 1292 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (attrs, size) = _3 in
                                     (n, ARRAY(decl, attrs, size)) )
# 5751 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_parameter_opt) in
    Obj.repr(
# 1295 "src/kernel_internals/parsing/cparser.mly"
                                                  (
   let (n,decl) = _1 in (n, PROTO(decl,[],_4,false))
  )
# 5762 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'rest_par_list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_parameter_opt) in
    Obj.repr(
# 1299 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     let ghost = _5 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, ghost, isva))
                                   )
# 5777 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1307 "src/kernel_internals/parsing/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 5784 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_list_startscope))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1310 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _2 in
                                     (_1 :: params, isva)
                                   )
# 5794 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1315 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], false) )
# 5800 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    Obj.repr(
# 1316 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], true) )
# 5806 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1317 "src/kernel_internals/parsing/cparser.mly"
                                        ( let (params, isva) = _3 in
                                          (_2 :: params, isva)
                                        )
# 5816 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1324 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, _2) )
# 5824 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1325 "src/kernel_internals/parsing/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, (*CEA*) cabslu)) )
# 5833 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1327 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], (*CEA*) cabslu)) )
# 5840 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1328 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5848 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1333 "src/kernel_internals/parsing/cparser.mly"
                                      ( let (n, decl, a) = _2 in
                                        (n, applyPointer (fst _1) decl,
                                         a, snd _1)
                                      )
# 5859 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1341 "src/kernel_internals/parsing/cparser.mly"
                                                                  (
    let par_decl, isva = doOldParDecl _3 _5 in
    let n, decl = _1 in
    (n, PROTO(decl, par_decl, [],isva), ["FC_OLDSTYLEPROTO",[]])
  )
# 5873 "src/kernel_internals/parsing/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1357 "src/kernel_internals/parsing/cparser.mly"
                                               ( [_1] )
# 5880 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1358 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1::_3 )
# 5888 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1362 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([], false) )
# 5894 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1364 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 5903 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1366 "src/kernel_internals/parsing/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva)
                                          )
# 5915 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1372 "src/kernel_internals/parsing/cparser.mly"
                                          ( [_1] )
# 5922 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1373 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 :: _3 )
# 5930 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1378 "src/kernel_internals/parsing/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 5939 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1381 "src/kernel_internals/parsing/cparser.mly"
                                 ( let l = Errorloc.currentLoc () in
                                   ([], l) )
# 5946 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1383 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 5953 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1387 "src/kernel_internals/parsing/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then
                                   Errorloc.parse_error
                                     "attributes in type name";
                                 (fst _1, d)
                               )
# 5966 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1393 "src/kernel_internals/parsing/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 5973 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1396 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 5982 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1397 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 5989 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1404 "src/kernel_internals/parsing/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 6000 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1409 "src/kernel_internals/parsing/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 6008 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1412 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params,[], isva)
                                   )
# 6020 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1416 "src/kernel_internals/parsing/cparser.mly"
                                ( PROTO (_1, [],[], false) )
# 6028 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1420 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 6035 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1421 "src/kernel_internals/parsing/cparser.mly"
                                    ( JUSTBASE )
# 6041 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Filepath.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1425 "src/kernel_internals/parsing/cparser.mly"
          (
            let (loc, specs, decl) = _2 in
            let spec_loc =
              let loc = fst _1 in
              Option.map
                (fun (loc', spec) -> spec, (loc, loc'))
                (Logic_lexer.spec _1)
            in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            doFunctionDef spec_loc loc (trd3 _3) specs decl (fst3 _3)
          )
# 6062 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1439 "src/kernel_internals/parsing/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            (*OCAMLYACC BUG??? Format.printf "%a@." d_cabsloc (trd3 $2);*)
            doFunctionDef None ((*handleLoc*) loc) (trd3 _2) specs decl (fst3 _2)
          )
# 6076 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1450 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (fourth4 _2, fst _1, _2)
                            )
# 6086 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1456 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 6096 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'rest_par_list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_parameter_opt) in
    Obj.repr(
# 1461 "src/kernel_internals/parsing/cparser.mly"
    ( let (params, isva) = _3 in
      let ghost = _5 in
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      let fdec =
        (_1, PROTO(JUSTBASE, params, ghost, isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      let defSpec = [SpecType Tint] in (loc, defSpec, fdec)
    )
# 6114 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1473 "src/kernel_internals/parsing/cparser.mly"
    ( (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      (* Make the function declarator *)
      let fdec = (_1, PROTO(JUSTBASE, pardecl,[],isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      (loc, [SpecType Tint], fdec)
    )
# 6132 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_parameter_opt) in
    Obj.repr(
# 1483 "src/kernel_internals/parsing/cparser.mly"
  (
    let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_start_pos 1) in
    let fdec = (_1, PROTO(JUSTBASE,[],_4,false),[],loc) in
    announceFunctionName fdec;
    (loc, [SpecType Tint], fdec)
  )
# 6146 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1493 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_CONST), _1 )
# 6153 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1494 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_VOLATILE), _1 )
# 6160 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1495 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_RESTRICT), _1 )
# 6167 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1496 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_GHOST), _1 )
# 6174 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1498 "src/kernel_internals/parsing/cparser.mly"
    (
      let annot, loc = _1 in
      if String.compare annot "\\ghost" = 0 then begin
        let start = Parsing.symbol_start_pos () in
        let source = Cil_datatype.Position.of_lexing_pos start in
        Errorloc.parse_error ~source "Use of \\ghost out of ghost code"
      end else
        SpecCV(CV_ATTRIBUTE_ANNOT annot), loc
    )
# 6189 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1511 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 6195 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1512 "src/kernel_internals/parsing/cparser.mly"
                                 ( fst _1 :: _2 )
# 6203 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1518 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 6209 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1519 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 6217 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1520 "src/kernel_internals/parsing/cparser.mly"
                                                 (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3) in
      ("__asm__",
       [{ expr_node = CONSTANT(CONST_STRING (fst _3)); expr_loc = loc}])
      :: _5
    )
# 6232 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1531 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 6241 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1532 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 6249 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1533 "src/kernel_internals/parsing/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 6256 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1535 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__thread", []), _1 )
# 6263 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1536 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__thread",
                                           [make_expr (VARIABLE "c11")]),
                                          _1 )
# 6272 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    Obj.repr(
# 1542 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 6278 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv_list) in
    Obj.repr(
# 1543 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 6286 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1548 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 6293 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1549 "src/kernel_internals/parsing/cparser.mly"
                          ( ("const", []), _1 )
# 6300 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1550 "src/kernel_internals/parsing/cparser.mly"
                          ( ("restrict",[]), _1 )
# 6307 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1551 "src/kernel_internals/parsing/cparser.mly"
                          ( ("volatile",[]), _1 )
# 6314 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1552 "src/kernel_internals/parsing/cparser.mly"
                          ( ("ghost",[]), _1 )
# 6321 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1553 "src/kernel_internals/parsing/cparser.mly"
                          ( let annot, loc = _1 in
			    (Cil.mkAttrAnnot annot, []), loc )
# 6329 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1562 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3) )
# 6338 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1563 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2) )
# 6346 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1569 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 6353 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'just_attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1570 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 :: _2 )
# 6361 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1575 "src/kernel_internals/parsing/cparser.mly"
                             (
    PRAGMA (make_expr (VARIABLE ("")), _1)
  )
# 6370 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1578 "src/kernel_internals/parsing/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 6378 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1579 "src/kernel_internals/parsing/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 6387 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1580 "src/kernel_internals/parsing/cparser.mly"
                                        (
    PRAGMA (make_expr (VARIABLE (fst _1)), snd _1)
  )
# 6396 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1588 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE _1) )
# 6403 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1589 "src/kernel_internals/parsing/cparser.mly"
               ( make_expr (VARIABLE _1) )
# 6410 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1590 "src/kernel_internals/parsing/cparser.mly"
                          ( make_expr (VARIABLE ("default:" ^ fst _3)) )
# 6418 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1592 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE "aconst") )
# 6425 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1594 "src/kernel_internals/parsing/cparser.mly"
             ( make_expr (VARIABLE ("__noreturn__")) )
# 6432 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1595 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (VARIABLE (fst _1 ^ ":" ^ fst _3)) )
# 6440 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1599 "src/kernel_internals/parsing/cparser.mly"
            ( make_expr (CONSTANT(CONST_INT (fst _1))) )
# 6447 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1600 "src/kernel_internals/parsing/cparser.mly"
              ( make_expr (CONSTANT(CONST_FLOAT(fst _1))) )
# 6454 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'var_attr) in
    Obj.repr(
# 1601 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 6461 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1604 "src/kernel_internals/parsing/cparser.mly"
                  ( [_1] )
# 6468 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1605 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1::_2 )
# 6476 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1609 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 )
# 6483 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1610 "src/kernel_internals/parsing/cparser.mly"
                                       (
      _1 @ [make_expr (CONSTANT(CONST_STRING (fst _2)))]
    )
# 6493 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1613 "src/kernel_internals/parsing/cparser.mly"
                                                              (
      _1 @ ([make_expr (CONSTANT(CONST_STRING (fst _2)))] @ _3)
    )
# 6504 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1618 "src/kernel_internals/parsing/cparser.mly"
                           ( _1 )
# 6511 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1619 "src/kernel_internals/parsing/cparser.mly"
                    ( [make_expr (CONSTANT(CONST_STRING (fst _1)))] )
# 6518 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1622 "src/kernel_internals/parsing/cparser.mly"
               ( _1 )
# 6525 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1623 "src/kernel_internals/parsing/cparser.mly"
                       ( _2 )
# 6533 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1624 "src/kernel_internals/parsing/cparser.mly"
                    ( make_expr (CONSTANT(CONST_STRING (fst _1))) )
# 6540 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1627 "src/kernel_internals/parsing/cparser.mly"
                 ( _1 )
# 6547 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1628 "src/kernel_internals/parsing/cparser.mly"
                                            (
        let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
        make_expr (CALL({ expr_loc = loc; expr_node = VARIABLE _1}, _2,[])) )
# 6557 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1632 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc1 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      let loc2 = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 2, Parsing.rhs_end_pos 3) in
      let f = { expr_node = VARIABLE _1; expr_loc = loc1 } in
      let arg = { expr_node = VARIABLE ""; expr_loc = loc2 } in
      make_expr (CALL(f, [arg],[]))
    )
# 6571 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'param_attr_list_ne) in
    Obj.repr(
# 1641 "src/kernel_internals/parsing/cparser.mly"
                                   (
      let loc = Cil_datatype.Location.of_lexing_loc (Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1) in
      make_expr (CALL({ expr_node = VARIABLE ""; expr_loc = loc}, _1::_2,[])) )
# 6581 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1645 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROFPTR (_1, _3)))
# 6589 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1646 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)) )
# 6597 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1647 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (INDEX (_1, _3)) )
# 6605 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1654 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6612 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1655 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (EXPR_SIZEOF _2) )
# 6620 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1657 "src/kernel_internals/parsing/cparser.mly"
                          (let b, d = _3 in
                                         make_expr (TYPE_SIZEOF (b, d)) )
# 6630 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1660 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (EXPR_ALIGNOF _2) )
# 6638 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1661 "src/kernel_internals/parsing/cparser.mly"
                                        (let b, d = _3 in
                                         make_expr (TYPE_ALIGNOF (b, d)) )
# 6648 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1663 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (PLUS, _2)))
# 6656 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1664 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (MINUS, _2)) )
# 6664 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1665 "src/kernel_internals/parsing/cparser.mly"
                            (make_expr (UNARY (MEMOF, _2)) )
# 6672 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1667 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (ADDROF, _2)) )
# 6680 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1668 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (NOT, _2)) )
# 6688 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1669 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (UNARY (BNOT, _2)) )
# 6696 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1673 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6703 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1677 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6710 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1678 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(MUL ,_1 , _3)))
# 6719 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1679 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(DIV ,_1 , _3)))
# 6727 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1680 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(MOD ,_1 , _3)))
# 6735 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1685 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6742 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1686 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(ADD ,_1 , _3)))
# 6751 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1687 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(SUB ,_1 , _3)))
# 6760 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1691 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6767 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1692 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHL ,_1 , _3)))
# 6775 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1693 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHR ,_1 , _3)))
# 6783 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1697 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6790 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1698 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(LT ,_1 , _3)))
# 6798 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1699 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(GT ,_1 , _3)))
# 6806 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1700 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(LE ,_1 , _3)))
# 6814 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1701 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(GE ,_1 , _3)))
# 6822 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1705 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6829 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1706 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(EQ ,_1 , _3)))
# 6837 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1707 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(NE ,_1 , _3)))
# 6845 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1712 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6852 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1713 "src/kernel_internals/parsing/cparser.mly"
                                       (make_expr (BINARY(BAND ,_1 , _3)))
# 6861 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1717 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6868 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1718 "src/kernel_internals/parsing/cparser.mly"
                                           (make_expr (BINARY(XOR ,_1 , _3)))
# 6876 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1722 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 6883 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1723 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(BOR ,_1 , _3)))
# 6891 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1727 "src/kernel_internals/parsing/cparser.mly"
                                                ( _1 )
# 6898 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1729 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(AND ,_1 , _3)))
# 6907 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1733 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1 )
# 6914 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1735 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(OR ,_1 , _3)))
# 6922 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1739 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6929 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'attr_test) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1741 "src/kernel_internals/parsing/cparser.mly"
    ( make_expr (QUESTION(_1, _4, _6)) )
# 6939 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1744 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 )
# 6946 "src/kernel_internals/parsing/cparser.ml"
               : 'assign_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1745 "src/kernel_internals/parsing/cparser.mly"
                                         ( make_expr (BINARY(ASSIGN,_1,_3)) )
# 6954 "src/kernel_internals/parsing/cparser.ml"
               : 'assign_attr))
; (fun __caml_parser_env ->
    Obj.repr(
# 1749 "src/kernel_internals/parsing/cparser.mly"
              ( Cabshelper.push_attr_test () )
# 6960 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_test))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assign_attr) in
    Obj.repr(
# 1751 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6967 "src/kernel_internals/parsing/cparser.ml"
               : 'attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr) in
    Obj.repr(
# 1755 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 6974 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1756 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 6982 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1760 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 6988 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1761 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 )
# 6995 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1764 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 7003 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list) in
    Obj.repr(
# 1767 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 7011 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1771 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 7017 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1772 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 7025 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1773 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("const", []) :: _2 )
# 7033 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 1776 "src/kernel_internals/parsing/cparser.mly"
                                       ( [intlist_to_string [fst _1]] )
# 7040 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1777 "src/kernel_internals/parsing/cparser.mly"
                                       ( intlist_to_string [fst _1] :: _2 )
# 7048 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    Obj.repr(
# 1780 "src/kernel_internals/parsing/cparser.mly"
                        ( None )
# 7054 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asminputs) in
    Obj.repr(
# 1782 "src/kernel_internals/parsing/cparser.mly"
                        ( let (ins, (clobs,labels)) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs;
				alabels = labels } )
# 7064 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1787 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 7070 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1788 "src/kernel_internals/parsing/cparser.mly"
                                        ( List.rev _1 )
# 7077 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1791 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 7084 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'asmoperandsne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1792 "src/kernel_internals/parsing/cparser.mly"
                                        ( _3 :: _1 )
# 7092 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'asmopname) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1795 "src/kernel_internals/parsing/cparser.mly"
                                                           ( (_1, fst _2, _4) )
# 7102 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    Obj.repr(
# 1798 "src/kernel_internals/parsing/cparser.mly"
                        ( ([], ([],[])) )
# 7108 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1800 "src/kernel_internals/parsing/cparser.mly"
                        ( (_2, _3) )
# 7116 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1803 "src/kernel_internals/parsing/cparser.mly"
                                        ( None )
# 7122 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 1804 "src/kernel_internals/parsing/cparser.mly"
                                        ( Some _2 )
# 7129 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    Obj.repr(
# 1808 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],[] )
# 7135 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1809 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],_2 )
# 7142 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmcloberlst_ne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1810 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2,_3 )
# 7150 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1813 "src/kernel_internals/parsing/cparser.mly"
                                    ( [fst _1] )
# 7157 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1814 "src/kernel_internals/parsing/cparser.mly"
                                             ( fst _1 :: _3 )
# 7165 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1817 "src/kernel_internals/parsing/cparser.mly"
                                       ( [] )
# 7171 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1818 "src/kernel_internals/parsing/cparser.mly"
                                       ( _2 )
# 7178 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
(* Entry interpret *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : (bool*Cabs.definition) list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 2 lexfun lexbuf : (bool*Cabs.definition) list)
;;
